struct
	cpuinfo_mock_file
		filesystem
			[] =
				{
					{
						.path = "/proc/cpuinfo",
						.size = 1662,
						.content = "processor\t: 0\n"
							   "Processor\t: AArch64 Processor rev 1 (aarch64)\n"
							   "model name\t: AArch64 Processor rev 1 (aarch64)\n"
							   "BogoMIPS\t: 26.00\n"
							   "Features\t: fp asimd evtstrm aes pmull sha1 sha2 crc32\n"
							   "CPU implementer\t: 0x41\n"
							   "CPU architecture: 8\n"
							   "CPU variant\t: 0x0\n"
							   "CPU part\t: 0xd04\n"
							   "CPU revision\t: 1\n"
							   "\n"
							   "processor\t: 1\n"
							   "Processor\t: AArch64 Processor rev 1 (aarch64)\n"
							   "model name\t: AArch64 Processor rev 1 (aarch64)\n"
							   "BogoMIPS\t: 26.00\n"
							   "Features\t: fp asimd evtstrm aes pmull sha1 sha2 crc32\n"
							   "CPU implementer\t: 0x41\n"
							   "CPU architecture: 8\n"
							   "CPU variant\t: 0x0\n"
							   "CPU part\t: 0xd04\n"
							   "CPU revision\t: 1\n"
							   "\n"
							   "processor\t: 2\n"
							   "Processor\t: AArch64 Processor rev 1 (aarch64)\n"
							   "model name\t: AArch64 Processor rev 1 (aarch64)\n"
							   "BogoMIPS\t: 26.00\n"
							   "Features\t: fp asimd evtstrm aes pmull sha1 sha2 crc32\n"
							   "CPU implementer\t: 0x41\n"
							   "CPU architecture: 8\n"
							   "CPU variant\t: 0x0\n"
							   "CPU part\t: 0xd04\n"
							   "CPU revision\t: 1\n"
							   "\n"
							   "processor\t: 3\n"
							   "Processor\t: AArch64 Processor rev 1 (aarch64)\n"
							   "model name\t: AArch64 Processor rev 1 (aarch64)\n"
							   "BogoMIPS\t: 26.00\n"
							   "Features\t: fp asimd evtstrm aes pmull sha1 sha2 crc32\n"
							   "CPU implementer\t: 0x41\n"
							   "CPU architecture: 8\n"
							   "CPU variant\t: 0x0\n"
							   "CPU part\t: 0xd04\n"
							   "CPU revision\t: 1\n"
							   "\n"
							   "processor\t: 4\n"
							   "Processor\t: AArch64 Processor rev 4 (aarch64)\n"
							   "model name\t: AArch64 Processor rev 4 (aarch64)\n"
							   "BogoMIPS\t: 26.00\n"
							   "Features\t: fp asimd evtstrm aes pmull sha1 sha2 crc32\n"
							   "CPU implementer\t: 0x41\n"
							   "CPU architecture: 8\n"
							   "CPU variant\t: 0x0\n"
							   "CPU part\t: 0xd03\n"
							   "CPU revision\t: 4\n"
							   "\n"
							   "processor\t: 8\n"
							   "Processor\t: AArch64 Processor rev 2 (aarch64)\n"
							   "model name\t: AArch64 Processor rev 2 (aarch64)\n"
							   "BogoMIPS\t: 26.00\n"
							   "Features\t: fp asimd evtstrm aes pmull sha1 sha2 crc32\n"
							   "CPU implementer\t: 0x41\n"
							   "CPU architecture: 8\n"
							   "CPU variant\t: 0x0\n"
							   "CPU part\t: 0xd09\n"
							   "CPU revision\t: 2\n"
							   "\n"
							   "Hardware\t: mt6799\n",
					},
					{
						.path = "/system/build.prop",
						.size = 10516,
						.content =
							"\n"
							"# begin build properties\n"
							"# autogenerated by buildinfo.sh\n"
							"ro.build.cta=noncta\n"
							"ro.meizu.build.spt=0\n"
							"ro.build.id=NRD90M\n"
							"ro.build.mask.id=7.0-1501681220_stable\n"
							"ro.build.inside.id=7.0-20170802214020\n"
							"ro.build.version.incremental=1501682079\n"
							"ro.build.version.sdk=24\n"
							"ro.build.version.preview_sdk=0\n"
							"ro.build.version.codename=REL\n"
							"ro.build.version.all_codenames=REL\n"
							"ro.build.version.release=7.0\n"
							"ro.build.version.security_patch=2017-04-05\n"
							"ro.build.version.base_os=\n"
							"ro.build.date=Wed Aug  2 21:54:37 CST 2017\n"
							"ro.build.date.utc=1501682077\n"
							"ro.build.type=user\n"
							"ro.build.user=flyme\n"
							"ro.build.host=mz-builder-5\n"
							"ro.build.tags=release-keys\n"
							"ro.build.flavor=full_mz6799_6m_v2_2k_n-user\n"
							"# ro.product.cpu.abi and ro.product.cpu.abi2 are obsolete,\n"
							"# use ro.product.cpu.abilist instead.\n"
							"ro.product.cpu.abi=arm64-v8a\n"
							"ro.product.cpu.abilist=arm64-v8a,armeabi-v7a,armeabi\n"
							"ro.product.cpu.abilist32=armeabi-v7a,armeabi\n"
							"ro.product.cpu.abilist64=arm64-v8a\n"
							"ro.product.locale=en-US\n"
							"ro.wifi.channels=\n"
							"ro.board.platform=mt6799\n"
							"# ro.build.product is obsolete; use ro.product.device\n"
							"# Do not try to parse description, fingerprint, or thumbprint\n"
							"ro.build.characteristics=default\n"
							"ro.product.brand=Meizu\n"
							"ro.product.manufacturer=Meizu\n"
							"ro.build.display.id=Flyme 6.1.2.2A\n"
							"ro.product.model=PRO 7 Plus\n"
							"ro.meizu.product.model=PRO7Plus\n"
							"ro.product.name=meizu_PRO7Plus\n"
							"ro.product.device=PRO7Plus\n"
							"ro.product.board=PRO7Plus\n"
							"# ro.build.product is obsolete; use ro.product.device\n"
							"ro.build.product=PRO7Plus\n"
							"# Do not try to parse ro.build.description or .fingerprint\n"
							"ro.build.description=meizu_PRO7Plus-user 7.0 NRD90M 1501682079 release-keys\n"
							"ro.build.fingerprint=Meizu/meizu_PRO7Plus/PRO7Plus:7.0/NRD90M/1501682079:user/release-keys\n"
							"ro.meizu.project.id=m1793-6\n"
							"ro.product.flyme.model=m1793\n"
							"ro.flyme.published = true\n"
							"# end build properties\n"
							"ro.meizu.build.number=201708022204\n"
							"#\n"
							"# from device/mediatek/mz6799_6m_v2_2k_n/system.prop\n"
							"#\n"
							"#\n"
							"# system.prop for generic sdk\n"
							"#\n"
							"\n"
							"rild.libpath=mtk-ril.so\n"
							"rild.libargs=-d /dev/ttyC0\n"
							"\n"
							"\n"
							"# MTK, Infinity, 20090720 {\n"
							"wifi.interface=wlan0\n"
							"# MTK, Infinity, 20090720 }\n"
							"\n"
							"# MTK, mtk03034, 20101210 {\n"
							"ro.mediatek.wlan.wsc=1\n"
							"# MTK, mtk03034 20101210}\n"
							"# MTK, mtk03034, 20110318 {\n"
							"ro.mediatek.wlan.p2p=1\n"
							"# MTK, mtk03034 20110318}\n"
							"\n"
							"# MTK, mtk03034, 20101213 {\n"
							"mediatek.wlan.ctia=0\n"
							"# MTK, mtk03034 20101213}\n"
							"\n"
							"\n"
							"#\n"
							"wifi.tethering.interface=ap0\n"
							"#\n"
							"\n"
							"ro.opengles.version=196610\n"
							"#ro.kernel.qemu=1\n"
							"# ro.kernel.qemu.gles=0\n"
							"\n"
							"wifi.direct.interface=p2p0\n"
							"#dalvik.vm.heapgrowthlimit=256m\n"
							"#dalvik.vm.heapsize=512m\n"
							"\n"
							"# USB MTP WHQL\n"
							"ro.sys.usb.mtp.whql.enable=0\n"
							"\n"
							"# Power off opt in IPO\n"
							"sys.ipo.pwrdncap=2\n"
							"\n"
							"ro.sys.usb.storage.type=mtp\n"
							"\n"
							"# USB BICR function\n"
							"ro.sys.usb.bicr=yes\n"
							"\n"
							"# USB Charge only function\n"
							"ro.sys.usb.charging.only=yes\n"
							"\n"
							"# audio\n"
							"ro.camera.sound.forced=0\n"
							"ro.audio.silent=0\n"
							"\n"
							"ro.zygote.preload.enable=0\n"
							"\n"
							"# temporary enables NAV bar (soft keys)\n"
							"qemu.hw.mainkeys=0\n"
							"\n"
							"ro.kernel.zio=38,108,105,16\n"
							"#ro.kernel.qemu=1\n"
							"#ro.kernel.qemu.gles=0\n"
							"#ro.boot.selinux=disable\n"
							"\n"
							"# Disable dirty region for Mali\n"
							"#debug.hwui.render_dirty_regions=false\n"
							"\n"
							"ro.sf.lcd_density=640\n"
							"\n"
							"# performance\n"
							"ro.mtk_perf_simple_start_win=1\n"
							"ro.mtk_perf_fast_start_win=1\n"
							"ro.mtk_perf_response_time=1\n"
							"\n"
							"# meizu mobile name\n"
							"ro.product.mobile.name=m1793\n"
							"\n"
							"#\n"
							"# ADDITIONAL_BUILD_PROPERTIES\n"
							"#\n"
							"ro.hardware.hifi.support=true\n"
							"ro.com.android.dateformat=MM-dd-yyyy\n"
							"ro.config.ringtone=03_Flyme.ogg\n"
							"ro.config.notification_sound=02_Reminder.ogg\n"
							"ro.config.mms_sound=01_Triumph.ogg\n"
							"ro.config.email_sound=02_Reminder.ogg\n"
							"ro.config.calendar_sound=03_Doorbell.ogg\n"
							"ro.config.alarm_alert=19_Waltz.ogg\n"
							"log.tag.VibeTonz=ERROR\n"
							"ro.carrier=unknown\n"
							"ro.mediatek.chip_ver=S01\n"
							"ro.mediatek.platform=MT6799\n"
							"ro.telephony.sim.count=2\n"
							"persist.radio.default.sim=0\n"
							"persist.sys.mtk_app_aal_support=1\n"
							"ril.specific.sm_cause=0\n"
							"bgw.current3gband=0\n"
							"ril.external.md=0\n"
							"ro.mtk_cam_lomo_support=1\n"
							"ro.sf.hwrotation=0\n"
							"persist.radio.fd.counter=150\n"
							"persist.radio.fd.off.counter=50\n"
							"persist.radio.fd.r8.counter=150\n"
							"persist.radio.fd.off.r8.counter=50\n"
							"drm.service.enabled=true\n"
							"fmradio.driver.enable=0\n"
							"mtk.eccci.c2k=enabled\n"
							"ril.first.md=1\n"
							"ril.flightmode.poweroffMD=0\n"
							"ril.telephony.mode=0\n"
							"dalvik.vm.mtk-stack-trace-file=/data/anr/mtk_traces.txt\n"
							"mediatek.wlan.chip=CONSYS_MT6799\n"
							"mediatek.wlan.module.postfix=_consys_mt6799\n"
							"ril.read.imsi=1\n"
							"ril.radiooff.poweroffMD=0\n"
							"ro.frp.pst=/dev/block/platform/bootdevice/by-name/frp\n"
							"ro.mtk_protocol1_rat_config=C/Lf/Lt/W/T/G\n"
							"ro.mtk_telephony_switch=1\n"
							"ro.mediatek.version.branch=alps-trunk-n0.tk\n"
							"ro.mediatek.version.release=alps-mp-n0.mp8\n"
							"ro.mediatek.version.sdk=4\n"
							"ro.num_md_protocol=2\n"
							"persist.radio.multisim.config=dsds\n"
							"ro.mtk_wapi_support=1\n"
							"ro.mtk_bt_support=1\n"
							"ro.mtk_wappush_support=1\n"
							"ro.mtk_agps_app=1\n"
							"ro.mtk_audio_tuning_tool_ver=V2.2\n"
							"ro.mtk_wlan_support=1\n"
							"ro.mtk_gps_support=1\n"
							"ro.mtk_omacp_support=1\n"
							"ro.mtk_search_db_support=1\n"
							"ro.mtk_dialer_search_support=1\n"
							"ro.mtk_dhcpv6c_wifi=1\n"
							"ro.have_aacencode_feature=1\n"
							"ro.mtk_fd_support=1\n"
							"ro.mtk_oma_drm_support=1\n"
							"ro.mtk_cta_drm_support=1\n"
							"ro.mtk_widevine_drm_l3_support=1\n"
							"ro.mtk_eap_sim_aka=1\n"
							"ro.mtk_send_rr_support=1\n"
							"ro.mtk_ufs_booting=1\n"
							"ro.mtk_tetheringipv6_support=1\n"
							"ro.mtk_c2k_support=1\n"
							"persist.radio.flashless.fsm=0\n"
							"persist.radio.flashless.fsm_cst=0\n"
							"persist.radio.flashless.fsm_rw=0\n"
							"ro.cdma.cfu.enable=*72\n"
							"ro.cdma.cfu.disable=*720\n"
							"ro.cdma.cfb.enable=*90\n"
							"ro.cdma.cfb.disable=*900\n"
							"ro.cdma.cfnr.enable=*92\n"
							"ro.cdma.cfnr.disable=*920\n"
							"ro.cdma.cfdf.enable=*68\n"
							"ro.cdma.cfdf.disable=*680\n"
							"ro.cdma.cfall.disable=*730\n"
							"ro.cdma.cw.enable=*74\n"
							"ro.cdma.cw.disable=*740\n"
							"telephony.lteOnCdmaDevice=1\n"
							"ro.telephony.default_network=10,10\n"
							"ro.mtk_shared_sdcard=1\n"
							"ro.mtk_enable_md1=1\n"
							"ro.mtk_enable_md3=1\n"
							"ro.mtk_afw_support=1\n"
							"ro.meizu_soter_support=1\n"
							"ro.mtk_aal_support=1\n"
							"ro.mtk_dre30_support=1\n"
							"ro.mtk_pq_support=3\n"
							"ro.mtk_pq_color_mode=1\n"
							"ro.mtk_blulight_def_support=1\n"
							"ro.mtk_wfd_support=1\n"
							"ro.mtk_wifi_mcc_support=1\n"
							"ro.mtk_sim_hot_swap=1\n"
							"ro.mtk_bip_scws=1\n"
							"ro.mtk_world_phone_policy=0\n"
							"ro.mtk_md_world_mode_support=1\n"
							"ro.mtk_perfservice_support=1\n"
							"ro.mtk_sim_hot_swap_common_slot=1\n"
							"ro.mtk_cta_set=1\n"
							"ro.mtk_devreg_app=1\n"
							"ro.mtk_ct4greg_app=1\n"
							"ro.mtk_zsdhdr_support=1\n"
							"ro.mtk_cam_mfb_support=3\n"
							"ro.mtk_cam_dualdenoise_support=1\n"
							"ro.mtk_slow_motion_support=1\n"
							"ro.mtk_cam_img_refocus_support=1\n"
							"ro.mtk_lte_support=1\n"
							"ro.mtk_rild_read_imsi=1\n"
							"ro.sim_refresh_reset_by_modem=1\n"
							"ro.mtk_external_sim_support=1\n"
							"ro.mtk_external_sim_only_slots=0\n"
							"ro.mtk_bg_power_saving_ui=1\n"
							"ro.sim_me_lock_mode=0\n"
							"ro.ap_info_monitor=0\n"
							"ro.mtk_dual_mic_support=1\n"
							"ro.mtk_is_tablet=0\n"
							"ro.mtk_pow_perf_support=1\n"
							"persist.mtk_nlp_switch_support=1\n"
							"persist.mtk_ims_support=1\n"
							"ro.mtk_multiple_ims_support=1\n"
							"persist.mtk_volte_support=1\n"
							"persist.mtk.volte.enable=1\n"
							"persist.mtk_vilte_support=0\n"
							"ro.mtk_vilte_ut_support=0\n"
							"wfd.dummy.enable=1\n"
							"wfd.iframesize.level=0\n"
							"ro.mediatek.project.path=device/mediatek/mz6799_6m_v2_2k_n\n"
							"ro.mtk_microtrust_tee_support=1\n"
							"ro.flyme_softsim_mtee_enable=1\n"
							"persist.mtk.wcn.combo.chipid=-1\n"
							"persist.mtk.wcn.patch.version=-1\n"
							"persist.mtk.wcn.dynamic.dump=0\n"
							"service.wcn.driver.ready=no\n"
							"service.wcn.coredump.mode=0\n"
							"persist.mtk.connsys.poweron.ctl=0\n"
							"ro.com.android.mobiledata=true\n"
							"persist.radio.mobile.data=0,0\n"
							"persist.radio.fourgOff=1\n"
							"persist.meta.dumpdata=0\n"
							"ro.mtk_deinterlace_support=1\n"
							"ro.mtk_md_direct_tethering=1\n"
							"ro.tethering.bridge.interface=mdbr0\n"
							"sys.mtk_md_direct_tether_enable=true\n"
							"persist.radio.mtk_dsbp_support=1\n"
							"persist.radio.mtk_ps2_rat=W/G\n"
							"persist.radio.mtk_ps3_rat=G\n"
							"ro.boot.opt_c2k_lte_mode=2\n"
							"ro.boot.opt_md1_support=12\n"
							"ro.boot.opt_md3_support=2\n"
							"ro.boot.opt_lte_support=1\n"
							"ro.boot.opt_irat_support=1\n"
							"persist.log.tag.DCT=D\n"
							"ro.boot.opt_eccci_c2k=1\n"
							"ro.boot.opt_using_default=1\n"
							"ro.boot.opt_c2k_support=1\n"
							"persist.log.tag.C2K_AT=I\n"
							"persist.log.tag.C2K_RILC=I\n"
							"persist.log.tag.C2K_ATConfig=I\n"
							"persist.log.tag.LIBC2K_RIL=I\n"
							"mtk.vdec.waitkeyframeforplay=1\n"
							"ro.sys.sdcardfs=1\n"
							"ro.mtk_res_switch=1\n"
							"ro.mtk_hdr_video_support=1\n"
							"ro.ksc5601_write=0\n"
							"ro.email_support_ucs2=0\n"
							"ro.ussd_ksc5601=0\n"
							"persist.log.tag.CdmaMoSms=I\n"
							"persist.log.tag.CdmaMtSms=I\n"
							"ro.mtk_log_hide_gps=0\n"
							"ro.mtk_modem_monitor_support=1\n"
							"ro.have_aee_feature=1\n"
							"persist.sf.dualdisplay=1\n"
							"persist.perf.url.wxhb=http://wx.gtimg.com/hongbao/1701/hb.png\n"
							"debug.hwui.render_dirty_regions=true\n"
							"ro.hwui.disable_asset_atlas=true\n"
							"dalvik.vm.heapgrowthlimit=256m\n"
							"dalvik.vm.heapsize=512m\n"
							"ro.mtk_benchmark_boost_tp=1\n"
							"ro.hwui.texture_cache_size=120\n"
							"ro.hwui.layer_cache_size=60\n"
							"ro.hwui.fbo_cache_size=60\n"
							"ro.hwui.path_cache_size=60\n"
							"ro.hwui.r_buffer_cache_size=9\n"
							"ro.hwui.texture_cache_flushrate=0.4\n"
							"ro.hwui.gradient_cache_size=4\n"
							"ro.hwui.drop_shadow_cache_size=8\n"
							"ro.hwui.text_small_cache_width=1024\n"
							"ro.hwui.text_small_cache_height=1024\n"
							"ro.hwui.text_large_cache_width=2048\n"
							"ro.hwui.text_large_cache_height=1024\n"
							"ro.product.perf.config=M1793_base\n"
							"persist.sf.startingwindow.gles=1\n"
							"persist.sys.plugin.path=/data/data/|/data/user/\n"
							"persist.sys.plugin.compiler=interpret-only\n"
							"persist.sys.app.compiler=speed\n"
							"persist.sys.app.thread=4\n"
							"persist.sys.mstore.dl.num=1\n"
							"persist.sf.ssr.controlbar=0\n"
							"persist.sys.lock.charge=true\n"
							"persist.sys.sf.camera=1\n"
							"persist.perf.wm_static_blur=true\n"
							"persist.thermalmanager.enable=true\n"
							"persist.thermalmanager.path=/vendor/bin/thermal_manager\n"
							"persist.thermalconfig.off=/vendor/etc/.tp/thermal.off.conf\n"
							"persist.thermalconfig.powersave=/vendor/etc/.tp/thermal.low.conf\n"
							"persist.thermalconfig.mid=/vendor/etc/.tp/thermal.mid.conf\n"
							"persist.thermalconfig.high=/vendor/etc/.tp/thermal.high.conf\n"
							"persist.mtkperfservice.enable=false\n"
							"debug.choreographer.janklog=false\n"
							"ro.meizu.ess.support=1\n"
							"persist.sys.timezone=Asia/Shanghai\n"
							"persist.sys.meizu.region=cn\n"
							"persist.sys.meizu.codepage=gbk\n"
							"ro.meizu.region.enable=true\n"
							"ro.meizu.contactmsg.auth=false\n"
							"ro.meizu.customize.pccw=false\n"
							"ro.meizu.autorecorder=true\n"
							"ro.meizu.visualvoicemail=true\n"
							"ro.meizu.permanentkey=false\n"
							"ro.meizu.sip.support=true\n"
							"ro.meizu.voip.support=false\n"
							"ro.meizu.setupwizard.flyme=true\n"
							"ro.meizu.setupwizard.setlang=true\n"
							"ro.meizu.security=false\n"
							"sys.meizu.m35x.white.config=false\n"
							"sys.meizu.white.config=false\n"
							"persist.sys.log-main.enable=0\n"
							"persist.sys.log-system.enable=0\n"
							"persist.sys.log-events.enable=0\n"
							"persist.sys.log-radio.enable=0\n"
							"persist.sys.use.flyme.icon=true\n"
							"ro.adb.secure=1\n"
							"persist.sys.ui.hw=true\n"
							"keyguard.no_require_sim=true\n"
							"persist.sys.keyguard_intercept=true\n"
							"persist.sys.disable_blur_view=true\n"
							"persist.sys.static_blur_mode=false\n"
							"ro.meizu.published.type=prd\n"
							"ro.meizu.upgrade.config=false\n"
							"qemu.hw.mainkeys=1\n"
							"persist.sys.dalvik.vm.lib.2=libart.so\n"
							"dalvik.vm.isa.arm64.variant=cortex-a53\n"
							"dalvik.vm.isa.arm64.features=default\n"
							"dalvik.vm.isa.arm.variant=cortex-a53\n"
							"dalvik.vm.isa.arm.features=default\n"
							"net.bt.name=Android\n"
							"dalvik.vm.stack-trace-file=/data/anr/traces.txt\n"
							"ro.expect.recovery_id=0x89560126b36ef1427a8df246bc8b28e54e31ce82000000000000000000000000\n",
					},
					{
						.path = "/sys/devices/system/cpu/kernel_max",
						.size = 2,
						.content = "9\n",
					},
					{
						.path = "/sys/devices/system/cpu/possible",
						.size = 4,
						.content = "0-9\n",
					},
					{
						.path = "/sys/devices/system/cpu/present",
						.size = 4,
						.content = "0-9\n",
					},
					{
						.path = "/sys/devices/system/cpu/online",
						.size = 6,
						.content = "0-4,8\n",
					},
					{
						.path = "/sys/devices/system/cpu/offline",
						.size = 6,
						.content = "5-7,9\n",
					},
					{
						.path = "/sys/devices/system/cpu/modalias",
						.size = 66,
						.content =
							"cpu:type:aarch64:feature:,0000,0001,0002,0003,0004,0005,0006,0007\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpuidle/current_driver",
						.size = 18,
						.content = "mt67xx_v3_cpuidle\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpuidle/current_governor_ro",
						.size = 13,
						.content = "mtk_governor\n",
					},
					{
						.path = "/sys/devices/system/cpu/cputopo/cpus_per_cluster",
						.size = 39,
						.content = "cluster0: f\n"
							   "cluster1: f0\n"
							   "cluster2: 300\n",
					},
					{
						.path = "/sys/devices/system/cpu/cputopo/glbinfo",
						.size = 87,
						.content = "big/little arch: yes\n"
							   "nr_cups: 10\n"
							   "nr_clusters: 3\n"
							   "cluster0: f\n"
							   "cluster1: f0\n"
							   "cluster2: 300\n",
					},
					{
						.path = "/sys/devices/system/cpu/cputopo/is_big_little",
						.size = 2,
						.content = "1\n",
					},
					{
						.path = "/sys/devices/system/cpu/cputopo/is_multi_cluster",
						.size = 2,
						.content = "1\n",
					},
					{
						.path = "/sys/devices/system/cpu/cputopo/nr_clusters",
						.size = 2,
						.content = "3\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/affected_cpus",
						.size = 6,
						.content = "0 1 2\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "1898000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "249000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/related_cpus",
						.size = 8,
						.content = "0 1 2 3\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_frequencies",
						.size = 125,
						.content =
							"1898000 1863000 1828000 1769000 1678000 1604000 1512000 1421000 1347000 1237000 1145000 1005000 830000 648000 449000 249000 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq",
						.size = 8,
						.content = "1769000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "648000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/stats/time_in_state",
						.size = 187,
						.content = "1898000 1056\n"
							   "1863000 53\n"
							   "1828000 82\n"
							   "1769000 100\n"
							   "1678000 100\n"
							   "1604000 130\n"
							   "1512000 178\n"
							   "1421000 137\n"
							   "1347000 225\n"
							   "1237000 188\n"
							   "1145000 322\n"
							   "1005000 232\n"
							   "830000 214\n"
							   "648000 684\n"
							   "449000 326\n"
							   "249000 397\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/stats/total_trans",
						.size = 4,
						.content = "702\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/cpufreq/stats/trans_table",
						.size = 2941,
						.content =
							"   From  :    To\n"
							"         :   1898000   1863000   1828000   1769000   1678000   1604000   1512000   1421000   1347000   1237000   1145000   1005000    830000    648000    449000    249000 \n"
							"  1898000:         0        10        10         4         1         0         1         0         4         0         1         0         4         2         2         3 \n"
							"  1863000:        10         0         5         5         0         2         1         0         0         0         0         0         0         0         0         0 \n"
							"  1828000:        10         5         0         4         4         1         2         1         0         0         0         0         0         0         0         0 \n"
							"  1769000:         2         4         9         0        10         5         2         1         1         0         0         0         0         0         0         0 \n"
							"  1678000:         3         4         3         8         0         7         8         6         0         0         1         0         0         0         0         0 \n"
							"  1604000:         1         0         0         8        18         0        12         2         3         1         3         0         0         1         0         0 \n"
							"  1512000:         0         0         0         4         2        20         0        13        13         7         4         0         0         0         0         0 \n"
							"  1421000:         0         0         0         0         1        10        14         0        15         7         2         3         2         0         0         0 \n"
							"  1347000:         0         0         0         1         4         2        16        16         0        11        16         2         0         1         0         0 \n"
							"  1237000:         1         0         0         0         0         0         4         8        21         0        24         7         2         0         0         0 \n"
							"  1145000:         2         0         0         0         0         1         4         3         9        30         0        26         6         0         2         0 \n"
							"  1005000:         1         0         0         0         0         1         0         1         2         9        26         0        14         4         0         0 \n"
							"   830000:         3         0         0         0         0         0         0         2         0         0         6        16         0        12         1         1 \n"
							"   648000:         2         0         0         0         0         0         0         1         0         2         0         4        13         0         1         4 \n"
							"   449000:         1         0         0         0         0         0         0         0         0         0         0         0         0         6         0         5 \n"
							"   249000:         6         0         0         0         0         0         0         0         0         0         0         0         0         1         6         0 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/topology/physical_package_id",
						.size = 2,
						.content = "0\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/topology/core_siblings_list",
						.size = 4,
						.content = "0-3\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/topology/core_siblings",
						.size = 4,
						.content = "00f\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/topology/core_id",
						.size = 2,
						.content = "0\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/topology/thread_siblings_list",
						.size = 2,
						.content = "0\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu0/topology/thread_siblings",
						.size = 4,
						.content = "001\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/affected_cpus",
						.size = 8,
						.content = "0 1 2 3\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "1898000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "249000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/related_cpus",
						.size = 8,
						.content = "0 1 2 3\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/scaling_available_frequencies",
						.size = 125,
						.content =
							"1898000 1863000 1828000 1769000 1678000 1604000 1512000 1421000 1347000 1237000 1145000 1005000 830000 648000 449000 249000 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/scaling_cur_freq",
						.size = 8,
						.content = "1604000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "648000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/stats/time_in_state",
						.size = 188,
						.content = "1898000 1193\n"
							   "1863000 83\n"
							   "1828000 113\n"
							   "1769000 117\n"
							   "1678000 111\n"
							   "1604000 141\n"
							   "1512000 184\n"
							   "1421000 139\n"
							   "1347000 229\n"
							   "1237000 188\n"
							   "1145000 322\n"
							   "1005000 232\n"
							   "830000 214\n"
							   "648000 684\n"
							   "449000 326\n"
							   "249000 397\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/stats/total_trans",
						.size = 4,
						.content = "754\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/cpufreq/stats/trans_table",
						.size = 2941,
						.content =
							"   From  :    To\n"
							"         :   1898000   1863000   1828000   1769000   1678000   1604000   1512000   1421000   1347000   1237000   1145000   1005000    830000    648000    449000    249000 \n"
							"  1898000:         0        16        15         6         1         0         1         1         4         0         1         0         4         2         2         3 \n"
							"  1863000:        18         0         8         6         0         2         1         0         0         0         0         0         0         0         0         0 \n"
							"  1828000:        15        11         0         5         4         1         2         1         0         0         0         0         0         0         0         0 \n"
							"  1769000:         3         4        11         0        10         6         3         1         2         0         0         0         0         0         0         0 \n"
							"  1678000:         3         4         3        10         0         7         8         6         0         0         1         0         0         0         0         0 \n"
							"  1604000:         1         0         1         8        18         0        13         2         3         1         3         0         0         1         0         0 \n"
							"  1512000:         0         0         0         4         4        21         0        13        13         7         4         0         0         0         0         0 \n"
							"  1421000:         0         0         1         0         1        10        14         0        15         7         2         3         2         0         0         0 \n"
							"  1347000:         0         0         0         1         4         3        16        16         0        11        16         2         0         1         0         0 \n"
							"  1237000:         1         0         0         0         0         0         4         8        21         0        24         7         2         0         0         0 \n"
							"  1145000:         2         0         0         0         0         1         4         3         9        30         0        26         6         0         2         0 \n"
							"  1005000:         1         0         0         0         0         1         0         1         2         9        26         0        14         4         0         0 \n"
							"   830000:         3         0         0         0         0         0         0         2         0         0         6        16         0        12         1         1 \n"
							"   648000:         2         0         0         0         0         0         0         1         0         2         0         4        13         0         1         4 \n"
							"   449000:         1         0         0         0         0         0         0         0         0         0         0         0         0         6         0         5 \n"
							"   249000:         6         0         0         0         0         0         0         0         0         0         0         0         0         1         6         0 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/topology/physical_package_id",
						.size = 2,
						.content = "0\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/topology/core_siblings_list",
						.size = 4,
						.content = "0-3\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/topology/core_siblings",
						.size = 4,
						.content = "00f\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/topology/core_id",
						.size = 2,
						.content = "1\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/topology/thread_siblings_list",
						.size = 2,
						.content = "1\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu1/topology/thread_siblings",
						.size = 4,
						.content = "002\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/affected_cpus",
						.size = 2,
						.content = "0\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "1898000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "249000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/related_cpus",
						.size = 8,
						.content = "0 1 2 3\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/scaling_available_frequencies",
						.size = 125,
						.content =
							"1898000 1863000 1828000 1769000 1678000 1604000 1512000 1421000 1347000 1237000 1145000 1005000 830000 648000 449000 249000 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/scaling_cur_freq",
						.size = 7,
						.content = "648000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "648000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/stats/time_in_state",
						.size = 189,
						.content = "1898000 1220\n"
							   "1863000 109\n"
							   "1828000 146\n"
							   "1769000 164\n"
							   "1678000 151\n"
							   "1604000 208\n"
							   "1512000 223\n"
							   "1421000 162\n"
							   "1347000 250\n"
							   "1237000 210\n"
							   "1145000 346\n"
							   "1005000 277\n"
							   "830000 266\n"
							   "648000 872\n"
							   "449000 326\n"
							   "249000 397\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/stats/total_trans",
						.size = 4,
						.content = "931\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu2/cpufreq/stats/trans_table",
						.size = 2941,
						.content =
							"   From  :    To\n"
							"         :   1898000   1863000   1828000   1769000   1678000   1604000   1512000   1421000   1347000   1237000   1145000   1005000    830000    648000    449000    249000 \n"
							"  1898000:         0        19        18         8         2         0         1         1         4         0         1         0         4         2         2         3 \n"
							"  1863000:        21         0        11        10         0         4         1         0         0         0         0         0         0         0         0         0 \n"
							"  1828000:        17        15         0         8         4         3         2         1         0         0         0         0         0         0         0         0 \n"
							"  1769000:         6         7        12         0        15         8         5         1         2         0         1         0         0         0         0         0 \n"
							"  1678000:         4         5         4        14         0        11        10         6         0         0         1         0         0         0         0         0 \n"
							"  1604000:         1         1         3        11        24         0        19         3         3         3         3         0         0         1         0         0 \n"
							"  1512000:         0         0         1         5         5        28         0        14        14         9         4         0         0         0         0         0 \n"
							"  1421000:         0         0         1         0         1        11        18         0        16         7         4         3         2         0         0         0 \n"
							"  1347000:         0         0         0         1         4         4        16        20         0        13        17         2         0         1         0         0 \n"
							"  1237000:         1         0         0         0         0         1         4        10        24         0        26         8         3         0         0         0 \n"
							"  1145000:         2         0         0         0         0         1         4         3        12        32         0        29         7         0         2         0 \n"
							"  1005000:         1         0         0         0         0         1         0         1         2        11        28         0        23         8         0         0 \n"
							"   830000:         3         0         0         0         0         0         0         2         0         0         7        21         0        21         1         1 \n"
							"   648000:         2         0         0         0         0         0         0         1         0         2         0        12        17         0         1         4 \n"
							"   449000:         1         0         0         0         0         0         0         0         0         0         0         0         0         6         0         5 \n"
							"   249000:         6         0         0         0         0         0         0         0         0         0         0         0         0         1         6         0 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/affected_cpus",
						.size = 2,
						.content = "0\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "1898000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "249000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/related_cpus",
						.size = 8,
						.content = "0 1 2 3\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/scaling_available_frequencies",
						.size = 125,
						.content =
							"1898000 1863000 1828000 1769000 1678000 1604000 1512000 1421000 1347000 1237000 1145000 1005000 830000 648000 449000 249000 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/scaling_cur_freq",
						.size = 7,
						.content = "648000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "648000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/stats/time_in_state",
						.size = 190,
						.content = "1898000 1220\n"
							   "1863000 109\n"
							   "1828000 146\n"
							   "1769000 164\n"
							   "1678000 151\n"
							   "1604000 208\n"
							   "1512000 223\n"
							   "1421000 162\n"
							   "1347000 250\n"
							   "1237000 210\n"
							   "1145000 346\n"
							   "1005000 288\n"
							   "830000 270\n"
							   "648000 1125\n"
							   "449000 326\n"
							   "249000 397\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/stats/total_trans",
						.size = 4,
						.content = "938\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu3/cpufreq/stats/trans_table",
						.size = 2941,
						.content = "   From  :    To\n"
							   "         :   1898000   1863000   1828000   1769000   1678000   1604000   1512000   1421000   1347000   1237000   1145000   1005000    830000    648000    449000    249000 \n"
							   "  1898000:         0        19        18         8         2         0         1         1         4         0         1         0         4         2         2         3 \n"
							   "  1863000:        21         0        11        10         0         4         1         0         0         0         0         0         0         0         0         0 \n"
							   "  1828000:        17        15         0         8         4         3         2         1         0         0         0         0         0         0         0         0 \n"
							   "  1769000:         6         7        12         0        15         8         5         1         2         0         1         0         0         0         0         0 \n"
							   "  1678000:         4         5         4        14         0        11        10         6         0         0         1         0         0         0         0         0 \n"
							   "  1604000:         1         1         3        11        24         0        19         3         3         3         3         0         0         1         0         0 \n"
							   "  1512000:         0         0         1         5         5        28         0        14        14         9         4         0         0         0         0         0 \n"
							   "  1421000:         0         0         1         0         1        11        18         0        16         7         4         3         2         0         0         0 \n"
							   "  1347000:         0         0         0         1         4         4        16        20         0        13        17         2         0         1         0         0 \n"
							   "  1237000:         1         0         0         0         0         1         4        10        24         0        26         8         3         0         0         0 \n"
							   "  1145000:         2         0         0         0         0         1         4         3        12        32         0        29         7         0         2         0 \n"
							   "  1005000:         1         0         0         0         0         1         0         1         2        11        28         0        24         9         0         0 \n"
							   "   830000:         3         0         0         0         0         0         0         2         0         0         7        21         0        23         1         1 \n"
							   "   648000:         2         0         0         0         0         0         0         1         0         2         0        14        18         0         1         4 \n"
							   "   449000:         1         0         0         0         0         0         0         0         0         0         0         0         0         6         0         5 \n"
							   "   249000:         6         0         0         0         0         0         0         0         0         0         0         0         0         1         6         0 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/affected_cpus",
						.size = 1,
						.content = "\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "2197000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "279000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/related_cpus",
						.size = 8,
						.content = "4 5 6 7\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_cur_freq",
						.size = 7,
						.content = "687000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_max_freq",
						.size = 8,
						.content = "2197000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "687000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/stats/time_in_state",
						.size = 185,
						.content = "2197000 1085\n"
							   "2157000 64\n"
							   "2117000 87\n"
							   "2040000 100\n"
							   "1917000 170\n"
							   "1818000 122\n"
							   "1694000 77\n"
							   "1571000 34\n"
							   "1472000 95\n"
							   "1324000 100\n"
							   "1200000 549\n"
							   "1053000 370\n"
							   "873000 236\n"
							   "687000 2183\n"
							   "484000 144\n"
							   "279000 450\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/stats/total_trans",
						.size = 4,
						.content = "582\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu4/cpufreq/stats/trans_table",
						.size = 2941,
						.content =
							"   From  :    To\n"
							"         :   2197000   2157000   2117000   2040000   1917000   1818000   1694000   1571000   1472000   1324000   1200000   1053000    873000    687000    484000    279000 \n"
							"  2197000:         0         8         5         4         1         3         2         0         0         1         3         1         0         0         0         0 \n"
							"  2157000:         8         0         3         4         1         2         0         2         0         0         0         0         0         1         0         0 \n"
							"  2117000:         8         3         0         3         2         2         2         0         2         0         0         0         0         0         1         0 \n"
							"  2040000:         5         2         7         0         5         1         3         1         3         1         0         0         0         0         0         2 \n"
							"  1917000:         2         4         4         7         0         4         1         3         1         2         4         0         0         0         0         0 \n"
							"  1818000:         2         3         3         7         7         0         2         0         2         0         2         0         0         1         0         0 \n"
							"  1694000:         1         0         0         1         2         8         0         3         2         2         1         0         0         0         0         0 \n"
							"  1571000:         0         0         0         0         2         5         3         0         2         1         1         0         0         1         0         0 \n"
							"  1472000:         0         0         1         3         1         4         1         5         0         4         4         4         2         0         0         0 \n"
							"  1324000:         0         1         0         0         4         0         1         0        12         0         6         0         1         0         0         1 \n"
							"  1200000:         2         0         0         0         6         0         2         0         3         9         0        18         3         7         0         0 \n"
							"  1053000:         0         0         0         0         0         0         1         0         1         4        16         0        23        10         2         1 \n"
							"   873000:         0         0         0         1         0         0         0         0         0         0         6        19         0        35         3         6 \n"
							"   687000:         0         0         0         0         0         0         1         1         0         1         5        14        33         0        15         6 \n"
							"   484000:         0         0         0         0         0         0         0         0         0         1         2         0         6        12         0        19 \n"
							"   279000:         0         0         0         0         1         0         1         0         0         0         0         2         2        10        19         0 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/affected_cpus",
						.size = 1,
						.content = "\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "2197000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "279000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/related_cpus",
						.size = 8,
						.content = "4 5 6 7\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/scaling_cur_freq",
						.size = 7,
						.content = "687000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/scaling_max_freq",
						.size = 8,
						.content = "2197000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "687000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/stats/time_in_state",
						.size = 185,
						.content = "2197000 1085\n"
							   "2157000 64\n"
							   "2117000 87\n"
							   "2040000 100\n"
							   "1917000 170\n"
							   "1818000 122\n"
							   "1694000 77\n"
							   "1571000 34\n"
							   "1472000 95\n"
							   "1324000 100\n"
							   "1200000 549\n"
							   "1053000 370\n"
							   "873000 236\n"
							   "687000 3187\n"
							   "484000 144\n"
							   "279000 450\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/stats/total_trans",
						.size = 4,
						.content = "582\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu5/cpufreq/stats/trans_table",
						.size = 2941,
						.content =
							"   From  :    To\n"
							"         :   2197000   2157000   2117000   2040000   1917000   1818000   1694000   1571000   1472000   1324000   1200000   1053000    873000    687000    484000    279000 \n"
							"  2197000:         0         8         5         4         1         3         2         0         0         1         3         1         0         0         0         0 \n"
							"  2157000:         8         0         3         4         1         2         0         2         0         0         0         0         0         1         0         0 \n"
							"  2117000:         8         3         0         3         2         2         2         0         2         0         0         0         0         0         1         0 \n"
							"  2040000:         5         2         7         0         5         1         3         1         3         1         0         0         0         0         0         2 \n"
							"  1917000:         2         4         4         7         0         4         1         3         1         2         4         0         0         0         0         0 \n"
							"  1818000:         2         3         3         7         7         0         2         0         2         0         2         0         0         1         0         0 \n"
							"  1694000:         1         0         0         1         2         8         0         3         2         2         1         0         0         0         0         0 \n"
							"  1571000:         0         0         0         0         2         5         3         0         2         1         1         0         0         1         0         0 \n"
							"  1472000:         0         0         1         3         1         4         1         5         0         4         4         4         2         0         0         0 \n"
							"  1324000:         0         1         0         0         4         0         1         0        12         0         6         0         1         0         0         1 \n"
							"  1200000:         2         0         0         0         6         0         2         0         3         9         0        18         3         7         0         0 \n"
							"  1053000:         0         0         0         0         0         0         1         0         1         4        16         0        23        10         2         1 \n"
							"   873000:         0         0         0         1         0         0         0         0         0         0         6        19         0        35         3         6 \n"
							"   687000:         0         0         0         0         0         0         1         1         0         1         5        14        33         0        15         6 \n"
							"   484000:         0         0         0         0         0         0         0         0         0         1         2         0         6        12         0        19 \n"
							"   279000:         0         0         0         0         1         0         1         0         0         0         0         2         2        10        19         0 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/affected_cpus",
						.size = 1,
						.content = "\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "2197000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "279000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/related_cpus",
						.size = 8,
						.content = "4 5 6 7\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/scaling_cur_freq",
						.size = 7,
						.content = "687000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/scaling_max_freq",
						.size = 8,
						.content = "2197000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "687000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/stats/time_in_state",
						.size = 185,
						.content = "2197000 1085\n"
							   "2157000 64\n"
							   "2117000 87\n"
							   "2040000 100\n"
							   "1917000 170\n"
							   "1818000 122\n"
							   "1694000 77\n"
							   "1571000 34\n"
							   "1472000 95\n"
							   "1324000 100\n"
							   "1200000 549\n"
							   "1053000 370\n"
							   "873000 236\n"
							   "687000 3449\n"
							   "484000 144\n"
							   "279000 450\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/stats/total_trans",
						.size = 4,
						.content = "582\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu6/cpufreq/stats/trans_table",
						.size = 2941,
						.content = "   From  :    To\n"
							   "         :   2197000   2157000   2117000   2040000   1917000   1818000   1694000   1571000   1472000   1324000   1200000   1053000    873000    687000    484000    279000 \n"
							   "  2197000:         0         8         5         4         1         3         2         0         0         1         3         1         0         0         0         0 \n"
							   "  2157000:         8         0         3         4         1         2         0         2         0         0         0         0         0         1         0         0 \n"
							   "  2117000:         8         3         0         3         2         2         2         0         2         0         0         0         0         0         1         0 \n"
							   "  2040000:         5         2         7         0         5         1         3         1         3         1         0         0         0         0         0         2 \n"
							   "  1917000:         2         4         4         7         0         4         1         3         1         2         4         0         0         0         0         0 \n"
							   "  1818000:         2         3         3         7         7         0         2         0         2         0         2         0         0         1         0         0 \n"
							   "  1694000:         1         0         0         1         2         8         0         3         2         2         1         0         0         0         0         0 \n"
							   "  1571000:         0         0         0         0         2         5         3         0         2         1         1         0         0         1         0         0 \n"
							   "  1472000:         0         0         1         3         1         4         1         5         0         4         4         4         2         0         0         0 \n"
							   "  1324000:         0         1         0         0         4         0         1         0        12         0         6         0         1         0         0         1 \n"
							   "  1200000:         2         0         0         0         6         0         2         0         3         9         0        18         3         7         0         0 \n"
							   "  1053000:         0         0         0         0         0         0         1         0         1         4        16         0        23        10         2         1 \n"
							   "   873000:         0         0         0         1         0         0         0         0         0         0         6        19         0        35         3         6 \n"
							   "   687000:         0         0         0         0         0         0         1         1         0         1         5        14        33         0        15         6 \n"
							   "   484000:         0         0         0         0         0         0         0         0         0         1         2         0         6        12         0        19 \n"
							   "   279000:         0         0         0         0         1         0         1         0         0         0         0         2         2        10        19         0 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/affected_cpus",
						.size = 1,
						.content = "\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "2197000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "279000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/related_cpus",
						.size = 8,
						.content = "4 5 6 7\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/scaling_cur_freq",
						.size = 7,
						.content = "687000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/scaling_max_freq",
						.size = 8,
						.content = "2197000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "687000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/stats/time_in_state",
						.size = 186,
						.content = "2197000 1085\n"
							   "2157000 64\n"
							   "2117000 87\n"
							   "2040000 100\n"
							   "1917000 174\n"
							   "1818000 122\n"
							   "1694000 77\n"
							   "1571000 36\n"
							   "1472000 104\n"
							   "1324000 160\n"
							   "1200000 556\n"
							   "1053000 372\n"
							   "873000 242\n"
							   "687000 4306\n"
							   "484000 144\n"
							   "279000 450\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/stats/total_trans",
						.size = 4,
						.content = "599\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu7/cpufreq/stats/trans_table",
						.size = 2941,
						.content =
							"   From  :    To\n"
							"         :   2197000   2157000   2117000   2040000   1917000   1818000   1694000   1571000   1472000   1324000   1200000   1053000    873000    687000    484000    279000 \n"
							"  2197000:         0         8         5         4         1         3         2         0         0         1         3         1         0         0         0         0 \n"
							"  2157000:         8         0         3         4         1         2         0         2         0         0         0         0         0         1         0         0 \n"
							"  2117000:         8         3         0         3         2         2         2         0         2         0         0         0         0         0         1         0 \n"
							"  2040000:         5         2         7         0         5         1         3         1         3         1         0         0         0         0         0         2 \n"
							"  1917000:         2         4         4         7         0         4         1         3         1         2         4         1         0         0         0         0 \n"
							"  1818000:         2         3         3         7         7         0         2         0         2         0         2         0         0         1         0         0 \n"
							"  1694000:         1         0         0         1         2         8         0         3         2         2         1         0         0         0         0         0 \n"
							"  1571000:         0         0         0         0         3         5         3         0         2         1         1         0         0         1         0         0 \n"
							"  1472000:         0         0         1         3         1         4         1         6         0         4         5         4         2         0         0         0 \n"
							"  1324000:         0         1         0         0         4         0         1         0        12         0         6         0         2         2         0         1 \n"
							"  1200000:         2         0         0         0         6         0         2         0         4        10         0        18         4         7         0         0 \n"
							"  1053000:         0         0         0         0         0         0         1         0         1         5        16         0        23        10         2         1 \n"
							"   873000:         0         0         0         1         0         0         0         0         0         0         8        19         0        36         3         6 \n"
							"   687000:         0         0         0         0         0         0         1         1         1         2         5        14        34         0        15         6 \n"
							"   484000:         0         0         0         0         0         0         0         0         0         1         2         0         6        12         0        19 \n"
							"   279000:         0         0         0         0         1         0         1         0         0         0         0         2         2        10        19         0 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/affected_cpus",
						.size = 1,
						.content = "\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "2600000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "328000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/related_cpus",
						.size = 4,
						.content = "8 9\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/scaling_cur_freq",
						.size = 7,
						.content = "771000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/scaling_max_freq",
						.size = 8,
						.content = "2452000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "771000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/stats/time_in_state",
						.size = 184,
						.content = "2600000 551\n"
							   "2452000 562\n"
							   "2408000 66\n"
							   "2318000 80\n"
							   "2173000 124\n"
							   "2057000 91\n"
							   "1911000 356\n"
							   "1766000 413\n"
							   "1649000 77\n"
							   "1475000 264\n"
							   "1329000 573\n"
							   "1169000 89\n"
							   "974000 179\n"
							   "771000 4387\n"
							   "551000 225\n"
							   "328000 313\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/stats/total_trans",
						.size = 4,
						.content = "474\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu8/cpufreq/stats/trans_table",
						.size = 2941,
						.content = "   From  :    To\n"
							   "         :   2600000   2452000   2408000   2318000   2173000   2057000   1911000   1766000   1649000   1475000   1329000   1169000    974000    771000    551000    328000 \n"
							   "  2600000:         0         0         0         0         0         0         1         0         0         0         1         0         0         0         1         1 \n"
							   "  2452000:         1         0         5         3         0         1         1         0         0         0         1         0         0         2         1         0 \n"
							   "  2408000:         1         4         0         6         3         1         3         0         0         0         1         0         0         0         0         0 \n"
							   "  2318000:         0         4         3         0         5         5         2         1         1         0         2         0         0         0         0         0 \n"
							   "  2173000:         0         3         7         5         0         4         0         0         2         3         1         1         2         0         0         0 \n"
							   "  2057000:         0         2         2         4         5         0         5         6         2         0         0         0         0         0         0         0 \n"
							   "  1911000:         0         1         1         4        10        11         0         2         2         2         4         1         1         4         0         0 \n"
							   "  1766000:         1         0         0         0         1         2         8         0         4         2         2         2         0         0         0         0 \n"
							   "  1649000:         1         0         0         1         0         1         7         7         0         5         2         3         0         1         0         0 \n"
							   "  1475000:         0         0         0         0         3         1         6         3         9         0         9         3         0         2         0         0 \n"
							   "  1329000:         0         1         0         0         1         0         6         1         2        12         0         6         1         1         0         0 \n"
							   "  1169000:         0         0         0         0         0         0         0         0         6         7         4         0         9         4         1         1 \n"
							   "   974000:         0         0         0         0         0         0         2         2         0         2         2         8         0        28         2         0 \n"
							   "   771000:         0         0         1         0         0         0         2         0         0         3         1         4        32         0        16         1 \n"
							   "   551000:         0         0         0         0         0         0         0         0         0         0         0         2         1        17         0        19 \n"
							   "   328000:         0         0         0         0         0         0         0         0         0         0         1         1         0         2        18         0 \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/affected_cpus",
						.size = 1,
						.content = "\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/cpuinfo_max_freq",
						.size = 8,
						.content = "2600000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/cpuinfo_min_freq",
						.size = 7,
						.content = "328000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/cpuinfo_transition_latency",
						.size = 5,
						.content = "1000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/related_cpus",
						.size = 4,
						.content = "8 9\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/scaling_available_governors",
						.size = 19,
						.content = "sched interactive \n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/scaling_cur_freq",
						.size = 7,
						.content = "771000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/scaling_driver",
						.size = 11,
						.content = "mt-cpufreq\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/scaling_governor",
						.size = 12,
						.content = "interactive\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/scaling_max_freq",
						.size = 8,
						.content = "2452000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/scaling_min_freq",
						.size = 7,
						.content = "771000\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/stats/time_in_state",
						.size = 184,
						.content = "2600000 551\n"
							   "2452000 562\n"
							   "2408000 66\n"
							   "2318000 80\n"
							   "2173000 124\n"
							   "2057000 91\n"
							   "1911000 356\n"
							   "1766000 413\n"
							   "1649000 77\n"
							   "1475000 264\n"
							   "1329000 573\n"
							   "1169000 89\n"
							   "974000 179\n"
							   "771000 5352\n"
							   "551000 225\n"
							   "328000 313\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/stats/total_trans",
						.size = 4,
						.content = "474\n",
					},
					{
						.path = "/sys/devices/system/cpu/cpu9/cpufreq/stats/trans_table",
						.size = 2941,
						.content =
							"   From  :    To\n"
							"         :   2600000   2452000   2408000   2318000   2173000   2057000   1911000   1766000   1649000   1475000   1329000   1169000    974000    771000    551000    328000 \n"
							"  2600000:         0         0         0         0         0         0         1         0         0         0         1         0         0         0         1         1 \n"
							"  2452000:         1         0         5         3         0         1         1         0         0         0         1         0         0         2         1         0 \n"
							"  2408000:         1         4         0         6         3         1         3         0         0         0         1         0         0         0         0         0 \n"
							"  2318000:         0         4         3         0         5         5         2         1         1         0         2         0         0         0         0         0 \n"
							"  2173000:         0         3         7         5         0         4         0         0         2         3         1         1         2         0         0         0 \n"
							"  2057000:         0         2         2         4         5         0         5         6         2         0         0         0         0         0         0         0 \n"
							"  1911000:         0         1         1         4        10        11         0         2         2         2         4         1         1         4         0         0 \n"
							"  1766000:         1         0         0         0         1         2         8         0         4         2         2         2         0         0         0         0 \n"
							"  1649000:         1         0         0         1         0         1         7         7         0         5         2         3         0         1         0         0 \n"
							"  1475000:         0         0         0         0         3         1         6         3         9         0         9         3         0         2         0         0 \n"
							"  1329000:         0         1         0         0         1         0         6         1         2        12         0         6         1         1         0         0 \n"
							"  1169000:         0         0         0         0         0         0         0         0         6         7         4         0         9         4         1         1 \n"
							"   974000:         0         0         0         0         0         0         2         2         0         2         2         8         0        28         2         0 \n"
							"   771000:         0         0         1         0         0         0         2         0         0         3         1         4        32         0        16         1 \n"
							"   551000:         0         0         0         0         0         0         0         0         0         0         0         2         1        17         0        19 \n"
							"   328000:         0         0         0         0         0         0         0         0         0         0         1         1         0         2        18         0 \n",
					},
					{NULL},
};

#ifdef __ANDROID__
struct cpuinfo_mock_property properties[] = {
	{
		.key = "af.music.outputid",
		.value = "3",
	},
	{
		.key = "bgw.current3gband",
		.value = "0",
	},
	{
		.key = "camera.disable_zsl_mode",
		.value = "1",
	},
	{
		.key = "cdma.ril.eboot",
		.value = "0",
	},
	{
		.key = "cdma.ril.ecclist",
		.value = "",
	},
	{
		.key = "cdma.ril.ecclist1",
		.value = "",
	},
	{
		.key = "cdma.version.baseband",
		.value = "SIXTH.CBP.MD.MP6.V1.3_P18, 2017/07/15 11:37",
	},
	{
		.key = "dalvik.vm.appimageformat",
		.value = "lz4",
	},
	{
		.key = "dalvik.vm.dex2oat-Xms",
		.value = "64m",
	},
	{
		.key = "dalvik.vm.dex2oat-Xmx",
		.value = "512m",
	},
	{
		.key = "dalvik.vm.heapgrowthlimit",
		.value = "256m",
	},
	{
		.key = "dalvik.vm.heapsize",
		.value = "512m",
	},
	{
		.key = "dalvik.vm.image-dex2oat-Xms",
		.value = "64m",
	},
	{
		.key = "dalvik.vm.image-dex2oat-Xmx",
		.value = "64m",
	},
	{
		.key = "dalvik.vm.isa.arm.features",
		.value = "default",
	},
	{
		.key = "dalvik.vm.isa.arm.variant",
		.value = "cortex-a53",
	},
	{
		.key = "dalvik.vm.isa.arm64.features",
		.value = "default",
	},
	{
		.key = "dalvik.vm.isa.arm64.variant",
		.value = "cortex-a53",
	},
	{
		.key = "dalvik.vm.mtk-stack-trace-file",
		.value = "/data/anr/mtk_traces.txt",
	},
	{
		.key = "dalvik.vm.stack-trace-file",
		.value = "/data/anr/traces.txt",
	},
	{
		.key = "dalvik.vm.usejit",
		.value = "true",
	},
	{
		.key = "dalvik.vm.usejitprofiles",
		.value = "true",
	},
	{
		.key = "debug.MB.running",
		.value = "0",
	},
	{
		.key = "debug.atrace.tags.enableflags",
		.value = "0",
	},
	{
		.key = "debug.choreographer.janklog",
		.value = "false",
	},
	{
		.key = "debug.force_rtl",
		.value = "0",
	},
	{
		.key = "debug.fp.info",
		.value = "0",
	},
	{
		.key = "debug.hwc.bq_count",
		.value = "4",
	},
	{
		.key = "debug.hwc.compose_level",
		.value = "0",
	},
	{
		.key = "debug.hwui.render_dirty_regions",
		.value = "true",
	},
	{
		.key = "debug.mdlogger.Running",
		.value = "0",
	},
	{
		.key = "debug.mdlogger.log2sd.path",
		.value = "internal_sd",
	},
	{
		.key = "debug.mtk.aee.reinit",
		.value = "done",
	},
	{
		.key = "debug.mtk.aee.status",
		.value = "free",
	},
	{
		.key = "debug.mtk.aee.status64",
		.value = "free",
	},
	{
		.key = "debug.mtklog.netlog.Running",
		.value = "0",
	},
	{
		.key = "debug.pq.adl.dbg",
		.value = "0",
	},
	{
		.key = "debug.pq.dshp.en",
		.value = "2",
	},
	{
		.key = "debug.pq.hdr.dbg",
		.value = "0",
	},
	{
		.key = "debug.pq.shp.en",
		.value = "2",
	},
	{
		.key = "dev.bootcomplete",
		.value = "1",
	},
	{
		.key = "drm.service.enabled",
		.value = "true",
	},
	{
		.key = "fmradio.driver.enable",
		.value = "0",
	},
	{
		.key = "gsm.baseband.capability",
		.value = "1023",
	},
	{
		.key = "gsm.current.phone-type",
		.value = "1,1",
	},
	{
		.key = "gsm.gcf.testmode",
		.value = "0",
	},
	{
		.key = "gsm.lte.ca.support",
		.value = "1",
	},
	{
		.key = "gsm.network.type",
		.value = "Unknown,Unknown",
	},
	{
		.key = "gsm.operator.alpha",
		.value = "",
	},
	{
		.key = "gsm.operator.alpha.2",
		.value = "",
	},
	{
		.key = "gsm.operator.iso-country",
		.value = "us",
	},
	{
		.key = "gsm.operator.isroaming",
		.value = "false,false",
	},
	{
		.key = "gsm.operator.numeric",
		.value = "310410",
	},
	{
		.key = "gsm.project.baseband",
		.value = "MZ6799_6M_V2_N(LWCTG_MP1)",
	},
	{
		.key = "gsm.project.baseband.2",
		.value = "MZ6799_6M_V2_N(LWCTG_MP1)",
	},
	{
		.key = "gsm.ril.cardtypeset",
		.value = "",
	},
	{
		.key = "gsm.ril.cardtypeset.2",
		.value = "",
	},
	{
		.key = "gsm.ril.ct3g",
		.value = "0",
	},
	{
		.key = "gsm.ril.ct3g.2",
		.value = "0",
	},
	{
		.key = "gsm.ril.eboot",
		.value = "-1",
	},
	{
		.key = "gsm.ril.fulluicctype",
		.value = "",
	},
	{
		.key = "gsm.ril.fulluicctype.2",
		.value = "",
	},
	{
		.key = "gsm.ril.init",
		.value = "1",
	},
	{
		.key = "gsm.ril.uicctype",
		.value = "",
	},
	{
		.key = "gsm.ril.uicctype.2",
		.value = "",
	},
	{
		.key = "gsm.serial",
		.value = "793QBDR6227XF",
	},
	{
		.key = "gsm.sim.operator.alpha",
		.value = ",",
	},
	{
		.key = "gsm.sim.operator.iso-country",
		.value = ",",
	},
	{
		.key = "gsm.sim.operator.numeric",
		.value = ",",
	},
	{
		.key = "gsm.sim.retry.pin1",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.pin1.2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.pin2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.pin2.2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.puk1",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.puk1.2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.puk2",
		.value = "",
	},
	{
		.key = "gsm.sim.retry.puk2.2",
		.value = "",
	},
	{
		.key = "gsm.sim.ril.mcc.mnc",
		.value = "",
	},
	{
		.key = "gsm.sim.ril.mcc.mnc.2",
		.value = "",
	},
	{
		.key = "gsm.sim.ril.phbready",
		.value = "",
	},
	{
		.key = "gsm.sim.ril.phbready.2",
		.value = "",
	},
	{
		.key = "gsm.sim.state",
		.value = "ABSENT,ABSENT",
	},
	{
		.key = "gsm.version.baseband",
		.value = "MOLY.LR12.W1645.MD.MP.V1.3.P59, 2017/07/17 11:33",
	},
	{
		.key = "gsm.version.baseband1",
		.value = "MOLY.LR12.W1645.MD.MP.V1.3.P59, 2017/07/17 11:33",
	},
	{
		.key = "gsm.version.ril-impl",
		.value = "android reference-ril 1.0",
	},
	{
		.key = "init.svc.DMAgent",
		.value = "running",
	},
	{
		.key = "init.svc.MPED",
		.value = "running",
	},
	{
		.key = "init.svc.MtkCodecService",
		.value = "running",
	},
	{
		.key = "init.svc.NvRAMAgent",
		.value = "running",
	},
	{
		.key = "init.svc.aal",
		.value = "running",
	},
	{
		.key = "init.svc.adbd",
		.value = "running",
	},
	{
		.key = "init.svc.agpsd",
		.value = "running",
	},
	{
		.key = "init.svc.audioserver",
		.value = "running",
	},
	{
		.key = "init.svc.batterywarning",
		.value = "running",
	},
	{
		.key = "init.svc.bootanim",
		.value = "stopped",
	},
	{
		.key = "init.svc.bootlogoupdater",
		.value = "stopped",
	},
	{
		.key = "init.svc.cameraserver",
		.value = "running",
	},
	{
		.key = "init.svc.ccci3_fsd",
		.value = "running",
	},
	{
		.key = "init.svc.ccci3_mdinit",
		.value = "running",
	},
	{
		.key = "init.svc.ccci_fsd",
		.value = "running",
	},
	{
		.key = "init.svc.ccci_mdinit",
		.value = "running",
	},
	{
		.key = "init.svc.clear-bcb",
		.value = "running",
	},
	{
		.key = "init.svc.console",
		.value = "running",
	},
	{
		.key = "init.svc.debuggerd",
		.value = "running",
	},
	{
		.key = "init.svc.debuggerd64",
		.value = "running",
	},
	{
		.key = "init.svc.drm",
		.value = "running",
	},
	{
		.key = "init.svc.emdlogger1",
		.value = "running",
	},
	{
		.key = "init.svc.emdlogger3",
		.value = "running",
	},
	{
		.key = "init.svc.enableswap",
		.value = "stopped",
	},
	{
		.key = "init.svc.fingerprintd",
		.value = "running",
	},
	{
		.key = "init.svc.flash_recovery",
		.value = "stopped",
	},
	{
		.key = "init.svc.flymed",
		.value = "running",
	},
	{
		.key = "init.svc.fuelgauged",
		.value = "running",
	},
	{
		.key = "init.svc.fuelgauged_nvram",
		.value = "stopped",
	},
	{
		.key = "init.svc.gatekeeperd",
		.value = "running",
	},
	{
		.key = "init.svc.ged_srv",
		.value = "running",
	},
	{
		.key = "init.svc.goodixfpd",
		.value = "running",
	},
	{
		.key = "init.svc.gsm0710muxd",
		.value = "running",
	},
	{
		.key = "init.svc.healthd",
		.value = "running",
	},
	{
		.key = "init.svc.ifaad",
		.value = "running",
	},
	{
		.key = "init.svc.immvibed",
		.value = "running",
	},
	{
		.key = "init.svc.installd",
		.value = "running",
	},
	{
		.key = "init.svc.keystore",
		.value = "running",
	},
	{
		.key = "init.svc.lmkd",
		.value = "running",
	},
	{
		.key = "init.svc.logd",
		.value = "running",
	},
	{
		.key = "init.svc.logd-reinit",
		.value = "stopped",
	},
	{
		.key = "init.svc.mal-daemon",
		.value = "running",
	},
	{
		.key = "init.svc.media",
		.value = "running",
	},
	{
		.key = "init.svc.mediacodec",
		.value = "running",
	},
	{
		.key = "init.svc.mediadrm",
		.value = "running",
	},
	{
		.key = "init.svc.mediaextractor",
		.value = "running",
	},
	{
		.key = "init.svc.mnld",
		.value = "running",
	},
	{
		.key = "init.svc.mobile_log_d",
		.value = "running",
	},
	{
		.key = "init.svc.mpower_manager",
		.value = "running",
	},
	{
		.key = "init.svc.msensord",
		.value = "stopped",
	},
	{
		.key = "init.svc.mtkFlpDaemon",
		.value = "running",
	},
	{
		.key = "init.svc.netd",
		.value = "running",
	},
	{
		.key = "init.svc.netdiag",
		.value = "running",
	},
	{
		.key = "init.svc.nvram_daemon",
		.value = "stopped",
	},
	{
		.key = "init.svc.p2p_supplicant",
		.value = "running",
	},
	{
		.key = "init.svc.perfd",
		.value = "running",
	},
	{
		.key = "init.svc.pq",
		.value = "running",
	},
	{
		.key = "init.svc.program_binary",
		.value = "running",
	},
	{
		.key = "init.svc.remosaic_daemon",
		.value = "running",
	},
	{
		.key = "init.svc.ril-daemon-mtk",
		.value = "running",
	},
	{
		.key = "init.svc.ril-proxy",
		.value = "running",
	},
	{
		.key = "init.svc.servicemanager",
		.value = "running",
	},
	{
		.key = "init.svc.slpd",
		.value = "running",
	},
	{
		.key = "init.svc.sn",
		.value = "running",
	},
	{
		.key = "init.svc.stp_dump",
		.value = "running",
	},
	{
		.key = "init.svc.surfaceflinger",
		.value = "running",
	},
	{
		.key = "init.svc.sysenv_daemon",
		.value = "running",
	},
	{
		.key = "init.svc.teei_daemon",
		.value = "running",
	},
	{
		.key = "init.svc.terservice",
		.value = "stopped",
	},
	{
		.key = "init.svc.thermal",
		.value = "running",
	},
	{
		.key = "init.svc.thermal_manager",
		.value = "stopped",
	},
	{
		.key = "init.svc.thermald",
		.value = "running",
	},
	{
		.key = "init.svc.thermalloadalgod",
		.value = "running",
	},
	{
		.key = "init.svc.ueventd",
		.value = "running",
	},
	{
		.key = "init.svc.viarild",
		.value = "running",
	},
	{
		.key = "init.svc.vold",
		.value = "running",
	},
	{
		.key = "init.svc.volte_imcb",
		.value = "stopped",
	},
	{
		.key = "init.svc.volte_stack",
		.value = "stopped",
	},
	{
		.key = "init.svc.volte_ua",
		.value = "stopped",
	},
	{
		.key = "init.svc.vtservice",
		.value = "running",
	},
	{
		.key = "init.svc.wifi2agps",
		.value = "running",
	},
	{
		.key = "init.svc.wmt_launcher",
		.value = "running",
	},
	{
		.key = "init.svc.wmt_loader",
		.value = "stopped",
	},
	{
		.key = "init.svc.zygote",
		.value = "running",
	},
	{
		.key = "init.svc.zygote_secondary",
		.value = "running",
	},
	{
		.key = "keyguard.no_require_sim",
		.value = "true",
	},
	{
		.key = "log.tag",
		.value = "I",
	},
	{
		.key = "log.tag.VibeTonz",
		.value = "ERROR",
	},
	{
		.key = "log.tag.WifiHW",
		.value = "W",
	},
	{
		.key = "logmuch.detect.delay",
		.value = "1",
	},
	{
		.key = "media.wfd.portrait",
		.value = "0",
	},
	{
		.key = "media.wfd.video-format",
		.value = "5",
	},
	{
		.key = "mediatek.wlan.chip",
		.value = "CONSYS_MT6799",
	},
	{
		.key = "mediatek.wlan.ctia",
		.value = "0",
	},
	{
		.key = "mediatek.wlan.module.postfix",
		.value = "_consys_mt6799",
	},
	{
		.key = "mtk.eccci.c2k",
		.value = "enabled",
	},
	{
		.key = "mtk.md1.status",
		.value = "ready",
	},
	{
		.key = "mtk.md3.status",
		.value = "ready",
	},
	{
		.key = "mtk.vdec.waitkeyframeforplay",
		.value = "1",
	},
	{
		.key = "mtk_wifi.fwpath",
		.value = "STA",
	},
	{
		.key = "net.bt.name",
		.value = "Android",
	},
	{
		.key = "net.cdma.boottimes",
		.value = "1",
	},
	{
		.key = "net.cdma.mdmstat",
		.value = "ready",
	},
	{
		.key = "net.cdma.via.card.state",
		.value = "locked_or_absent",
	},
	{
		.key = "net.cdma.via.service.state",
		.value = "out of service",
	},
	{
		.key = "net.change",
		.value = "net.dns2",
	},
	{
		.key = "net.dns1",
		.value = "208.67.222.222",
	},
	{
		.key = "net.dns2",
		.value = "208.67.220.220",
	},
	{
		.key = "net.handover.rat",
		.value = "0",
	},
	{
		.key = "net.handover.thlte",
		.value = "-116,-111,-106",
	},
	{
		.key = "net.hostname",
		.value = "android-8004874998a95272",
	},
	{
		.key = "net.nsiot_pending",
		.value = "false",
	},
	{
		.key = "net.perf.internal.cpu.core",
		.value = "4,4,0,0,0,0",
	},
	{
		.key = "net.perf.internal.cpu.freq",
		.value = "-1,-1,-1,-1,-1,-1",
	},
	{
		.key = "net.perf.rps.default",
		.value = "3ff",
	},
	{
		.key = "net.perf.tether.cpu.core",
		.value = "4,4,0,0,0,0",
	},
	{
		.key = "net.perf.tether.cpu.freq",
		.value = "1183000,1638000,0,0,0,0",
	},
	{
		.key = "net.perf.tether.rps",
		.value = "00f",
	},
	{
		.key = "net.qtaguid_enabled",
		.value = "1",
	},
	{
		.key = "net.tcp.default_init_rwnd",
		.value = "60",
	},
	{
		.key = "persist.bluetooth.disableabsvol",
		.value = "true",
	},
	{
		.key = "persist.dm.lock",
		.value = "false",
	},
	{
		.key = "persist.log.tag",
		.value = "",
	},
	{
		.key = "persist.log.tag.C2K_AT",
		.value = "I",
	},
	{
		.key = "persist.log.tag.C2K_ATConfig",
		.value = "I",
	},
	{
		.key = "persist.log.tag.C2K_RILC",
		.value = "I",
	},
	{
		.key = "persist.log.tag.CdmaMoSms",
		.value = "I",
	},
	{
		.key = "persist.log.tag.CdmaMtSms",
		.value = "I",
	},
	{
		.key = "persist.log.tag.DCT",
		.value = "D",
	},
	{
		.key = "persist.log.tag.LIBC2K_RIL",
		.value = "I",
	},
	{
		.key = "persist.meta.dumpdata",
		.value = "0",
	},
	{
		.key = "persist.mtk.connsys.poweron.ctl",
		.value = "0",
	},
	{
		.key = "persist.mtk.volte.enable",
		.value = "0",
	},
	{
		.key = "persist.mtk.wcn.combo.chipid",
		.value = "0x6632",
	},
	{
		.key = "persist.mtk.wcn.dynamic.dump",
		.value = "0",
	},
	{
		.key = "persist.mtk.wcn.patch.version",
		.value = "20170605b00100D",
	},
	{
		.key = "persist.mtk_ims_support",
		.value = "1",
	},
	{
		.key = "persist.mtk_nlp_switch_support",
		.value = "1",
	},
	{
		.key = "persist.mtk_vilte_support",
		.value = "0",
	},
	{
		.key = "persist.mtk_volte_support",
		.value = "1",
	},
	{
		.key = "persist.mtkperfservice.enable",
		.value = "false",
	},
	{
		.key = "persist.perf.url.wxhb",
		.value = "http://wx.gtimg.com/hongbao/1701/hb.png",
	},
	{
		.key = "persist.perf.wm_static_blur",
		.value = "true",
	},
	{
		.key = "persist.radio.cdma_slot",
		.value = "1",
	},
	{
		.key = "persist.radio.data.iccid",
		.value = "",
	},
	{
		.key = "persist.radio.default.sim",
		.value = "0",
	},
	{
		.key = "persist.radio.fd.counter",
		.value = "150",
	},
	{
		.key = "persist.radio.fd.off.counter",
		.value = "50",
	},
	{
		.key = "persist.radio.fd.off.r8.counter",
		.value = "50",
	},
	{
		.key = "persist.radio.fd.r8.counter",
		.value = "150",
	},
	{
		.key = "persist.radio.flashless.fsm",
		.value = "0",
	},
	{
		.key = "persist.radio.flashless.fsm_cst",
		.value = "0",
	},
	{
		.key = "persist.radio.flashless.fsm_rw",
		.value = "0",
	},
	{
		.key = "persist.radio.fourgOff",
		.value = "1",
	},
	{
		.key = "persist.radio.ia",
		.value = "",
	},
	{
		.key = "persist.radio.ia-apn",
		.value = "",
	},
	{
		.key = "persist.radio.lte.chip",
		.value = "0",
	},
	{
		.key = "persist.radio.mobile.data",
		.value = "0,0",
	},
	{
		.key = "persist.radio.mtk_dsbp_support",
		.value = "1",
	},
	{
		.key = "persist.radio.mtk_ps2_rat",
		.value = "W/G",
	},
	{
		.key = "persist.radio.mtk_ps3_rat",
		.value = "G",
	},
	{
		.key = "persist.radio.multisim.config",
		.value = "dsds",
	},
	{
		.key = "persist.radio.reset_on_switch",
		.value = "false",
	},
	{
		.key = "persist.radio.simswitch",
		.value = "1",
	},
	{
		.key = "persist.service.acm.enable",
		.value = "0",
	},
	{
		.key = "persist.service.bdroid.bdaddr",
		.value = "22:22:0f:a1:e7:36",
	},
	{
		.key = "persist.service.stk.shutdown",
		.value = "0",
	},
	{
		.key = "persist.sf.dualdisplay",
		.value = "1",
	},
	{
		.key = "persist.sf.ssr.controlbar",
		.value = "0",
	},
	{
		.key = "persist.sf.startingwindow.gles",
		.value = "1",
	},
	{
		.key = "persist.sys.app.compiler",
		.value = "speed",
	},
	{
		.key = "persist.sys.app.thread",
		.value = "4",
	},
	{
		.key = "persist.sys.bluelight.default",
		.value = "128",
	},
	{
		.key = "persist.sys.bluelight.enabled",
		.value = "0",
	},
	{
		.key = "persist.sys.dalvik.vm.lib.2",
		.value = "libart.so",
	},
	{
		.key = "persist.sys.disable_blur_view",
		.value = "true",
	},
	{
		.key = "persist.sys.enable.stepcounter",
		.value = "true",
	},
	{
		.key = "persist.sys.fast_charge",
		.value = "1",
	},
	{
		.key = "persist.sys.fingerprint.hbd",
		.value = "false",
	},
	{
		.key = "persist.sys.first_time_boot",
		.value = "false",
	},
	{
		.key = "persist.sys.get_stacks_perm",
		.value = "1",
	},
	{
		.key = "persist.sys.keyguard_intercept",
		.value = "true",
	},
	{
		.key = "persist.sys.lock.charge",
		.value = "true",
	},
	{
		.key = "persist.sys.log-events.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.log-main.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.log-radio.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.log-system.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.log_reject_level",
		.value = "3",
	},
	{
		.key = "persist.sys.meizu.codepage",
		.value = "gbk",
	},
	{
		.key = "persist.sys.meizu.region",
		.value = "cn",
	},
	{
		.key = "persist.sys.mstore.dl.num",
		.value = "1",
	},
	{
		.key = "persist.sys.mtk_app_aal_support",
		.value = "1",
	},
	{
		.key = "persist.sys.mute.state",
		.value = "2",
	},
	{
		.key = "persist.sys.plugin.compiler",
		.value = "interpret-only",
	},
	{
		.key = "persist.sys.plugin.path",
		.value = "/data/data/|/data/user/",
	},
	{
		.key = "persist.sys.pq.adl.idx",
		.value = "0",
	},
	{
		.key = "persist.sys.pq.hdr.en",
		.value = "1",
	},
	{
		.key = "persist.sys.pq.iso.shp.en",
		.value = "2",
	},
	{
		.key = "persist.sys.pq.log.en",
		.value = "0",
	},
	{
		.key = "persist.sys.pq.mdp.color.dbg",
		.value = "1",
	},
	{
		.key = "persist.sys.pq.mdp.color.idx",
		.value = "0",
	},
	{
		.key = "persist.sys.pq.shp.idx",
		.value = "2",
	},
	{
		.key = "persist.sys.pq.ultrares.en",
		.value = "2",
	},
	{
		.key = "persist.sys.profiler_ms",
		.value = "0",
	},
	{
		.key = "persist.sys.sd.defaultpath",
		.value = "/storage/emulated/0",
	},
	{
		.key = "persist.sys.sf.camera",
		.value = "1",
	},
	{
		.key = "persist.sys.static_blur_mode",
		.value = "false",
	},
	{
		.key = "persist.sys.timezone",
		.value = "Asia/Shanghai",
	},
	{
		.key = "persist.sys.ui.hw",
		.value = "true",
	},
	{
		.key = "persist.sys.usb.config",
		.value = "mtp,adb",
	},
	{
		.key = "persist.sys.use.flyme.icon",
		.value = "true",
	},
	{
		.key = "persist.sys.webview.vmsize",
		.value = "143153984",
	},
	{
		.key = "persist.thermalconfig.high",
		.value = "/vendor/etc/.tp/thermal.high.conf",
	},
	{
		.key = "persist.thermalconfig.mid",
		.value = "/vendor/etc/.tp/thermal.mid.conf",
	},
	{
		.key = "persist.thermalconfig.off",
		.value = "/vendor/etc/.tp/thermal.off.conf",
	},
	{
		.key = "persist.thermalconfig.powersave",
		.value = "/vendor/etc/.tp/thermal.low.conf",
	},
	{
		.key = "persist.thermalmanager.enable",
		.value = "true",
	},
	{
		.key = "persist.thermalmanager.path",
		.value = "/vendor/bin/thermal_manager",
	},
	{
		.key = "pm.dexopt.ab-ota",
		.value = "speed-profile",
	},
	{
		.key = "pm.dexopt.bg-dexopt",
		.value = "speed-profile",
	},
	{
		.key = "pm.dexopt.boot",
		.value = "verify-profile",
	},
	{
		.key = "pm.dexopt.core-app",
		.value = "speed",
	},
	{
		.key = "pm.dexopt.first-boot",
		.value = "interpret-only",
	},
	{
		.key = "pm.dexopt.forced-dexopt",
		.value = "speed",
	},
	{
		.key = "pm.dexopt.install",
		.value = "interpret-only",
	},
	{
		.key = "pm.dexopt.nsys-library",
		.value = "speed",
	},
	{
		.key = "pm.dexopt.shared-apk",
		.value = "speed",
	},
	{
		.key = "qemu.hw.mainkeys",
		.value = "1",
	},
	{
		.key = "recovery.service.support",
		.value = "true",
	},
	{
		.key = "ril.active.md",
		.value = "12",
	},
	{
		.key = "ril.cdma.card.omh",
		.value = "-1",
	},
	{
		.key = "ril.cdma.card.type.1",
		.value = "",
	},
	{
		.key = "ril.cdma.card.type.2",
		.value = "",
	},
	{
		.key = "ril.cdma.emdstatus.protocol",
		.value = "1,-1",
	},
	{
		.key = "ril.cdma.emdstatus.send",
		.value = "1",
	},
	{
		.key = "ril.cdma.enhance.version",
		.value = "1",
	},
	{
		.key = "ril.cdma.meid",
		.value = "86309803104951",
	},
	{
		.key = "ril.cdma.report",
		.value = "0",
	},
	{
		.key = "ril.cdma.report.case",
		.value = "0",
	},
	{
		.key = "ril.cdma.switching",
		.value = "0",
	},
	{
		.key = "ril.cdma.uimid",
		.value = "0",
	},
	{
		.key = "ril.ecc.service.category.list",
		.value = "",
	},
	{
		.key = "ril.ecclist",
		.value = "",
	},
	{
		.key = "ril.ecclist1",
		.value = "",
	},
	{
		.key = "ril.external.md",
		.value = "0",
	},
	{
		.key = "ril.fd.mode",
		.value = "1",
	},
	{
		.key = "ril.first.md",
		.value = "1",
	},
	{
		.key = "ril.flightmode.poweroffMD",
		.value = "0",
	},
	{
		.key = "ril.gsm.imei",
		.value = "863098031049497,863098031049505",
	},
	{
		.key = "ril.ia.iccid",
		.value = "",
	},
	{
		.key = "ril.iccid.sim1",
		.value = "N/A",
	},
	{
		.key = "ril.iccid.sim2",
		.value = "N/A",
	},
	{
		.key = "ril.imsi.status.sim1",
		.value = "0",
	},
	{
		.key = "ril.imsi.status.sim2",
		.value = "0",
	},
	{
		.key = "ril.ipo.radiooff",
		.value = "0",
	},
	{
		.key = "ril.ipo.radiooff.2",
		.value = "0",
	},
	{
		.key = "ril.mal.flag",
		.value = "0",
	},
	{
		.key = "ril.mal.socket",
		.value = "rilproxy-mal",
	},
	{
		.key = "ril.mux.ee.md1",
		.value = "0",
	},
	{
		.key = "ril.mux.report.case",
		.value = "0",
	},
	{
		.key = "ril.nw.erat.ext.support",
		.value = "1",
	},
	{
		.key = "ril.nw.worldmode.activemode",
		.value = "1",
	},
	{
		.key = "ril.nw.worldmode.keep_3g_mode",
		.value = "-1",
	},
	{
		.key = "ril.phone1.mapped.md",
		.value = "MD1",
	},
	{
		.key = "ril.pid.1",
		.value = "892",
	},
	{
		.key = "ril.radio.ia",
		.value = "",
	},
	{
		.key = "ril.radio.ia-apn",
		.value = "",
	},
	{
		.key = "ril.radiooff.poweroffMD",
		.value = "0",
	},
	{
		.key = "ril.read.imsi",
		.value = "1",
	},
	{
		.key = "ril.rilproxy",
		.value = "1",
	},
	{
		.key = "ril.specific.sm_cause",
		.value = "0",
	},
	{
		.key = "ril.telephony.mode",
		.value = "0",
	},
	{
		.key = "ril.uim.subscriberid.1",
		.value = "N/A",
	},
	{
		.key = "ril.uim.subscriberid.2",
		.value = "N/A",
	},
	{
		.key = "ril.volte.mal.latency",
		.value = "65535",
	},
	{
		.key = "ril.volte.mal.opkey",
		.value = "0x0001",
	},
	{
		.key = "ril.volte.mal.pkterrth",
		.value = "99",
	},
	{
		.key = "ril.volte.mal.pktlosth",
		.value = "99",
	},
	{
		.key = "ril.volte.mal.rb_hoddc_t",
		.value = "3",
	},
	{
		.key = "ril.volte.mal.rb_hol2w_t",
		.value = "10",
	},
	{
		.key = "ril.volte.mal.rb_how2l_t",
		.value = "150",
	},
	{
		.key = "ril.volte.mal.retranth",
		.value = "99",
	},
	{
		.key = "ril.volte.mal.throupt",
		.value = "65535",
	},
	{
		.key = "ril.volte.mal.vijit",
		.value = "3",
	},
	{
		.key = "ril.volte.mal.vojit",
		.value = "26",
	},
	{
		.key = "ril.volte.mal.vtcall_plr",
		.value = "200",
	},
	{
		.key = "ril.volte.mal.vtcall_rtl",
		.value = "300",
	},
	{
		.key = "rild.libargs",
		.value = "-d /dev/ttyC0",
	},
	{
		.key = "rild.libpath",
		.value = "mtk-ril.so",
	},
	{
		.key = "rild.mark_switchuser",
		.value = "0",
	},
	{
		.key = "ro.adb.secure",
		.value = "1",
	},
	{
		.key = "ro.aee.boost",
		.value = "on",
	},
	{
		.key = "ro.aee.enperf",
		.value = "off",
	},
	{
		.key = "ro.allow.mock.location",
		.value = "0",
	},
	{
		.key = "ro.ap_info_monitor",
		.value = "0",
	},
	{
		.key = "ro.audio.silent",
		.value = "0",
	},
	{
		.key = "ro.baseband",
		.value = "unknown",
	},
	{
		.key = "ro.board.platform",
		.value = "mt6799",
	},
	{
		.key = "ro.boot.bootreason",
		.value = "wdt_by_pass_pwk",
	},
	{
		.key = "ro.boot.flash.locked",
		.value = "1",
	},
	{
		.key = "ro.boot.hardware",
		.value = "mt6799",
	},
	{
		.key = "ro.boot.mode",
		.value = "normal",
	},
	{
		.key = "ro.boot.opt_c2k_lte_mode",
		.value = "2",
	},
	{
		.key = "ro.boot.opt_c2k_support",
		.value = "1",
	},
	{
		.key = "ro.boot.opt_eccci_c2k",
		.value = "1",
	},
	{
		.key = "ro.boot.opt_irat_support",
		.value = "1",
	},
	{
		.key = "ro.boot.opt_lte_support",
		.value = "1",
	},
	{
		.key = "ro.boot.opt_md1_support",
		.value = "12",
	},
	{
		.key = "ro.boot.opt_md3_support",
		.value = "2",
	},
	{
		.key = "ro.boot.opt_ps1_rat",
		.value = "C/Lf/Lt/W/T/G",
	},
	{
		.key = "ro.boot.opt_using_default",
		.value = "1",
	},
	{
		.key = "ro.boot.selinux",
		.value = "permissive",
	},
	{
		.key = "ro.boot.serialno",
		.value = "793QBDR6227XF",
	},
	{
		.key = "ro.boot.verifiedbootstate",
		.value = "green",
	},
	{
		.key = "ro.bootimage.build.date",
		.value = "Wed Aug 2 21:54:37 CST 2017",
	},
	{
		.key = "ro.bootimage.build.date.utc",
		.value = "1501682077",
	},
	{
		.key = "ro.bootimage.build.fingerprint",
		.value = "Meizu/full_mz6799_6m_v2_2k_n/mz6799_6m_v2_2k_n:7.0/NRD90M/1501682079:user/release-keys",
	},
	{
		.key = "ro.bootloader",
		.value = "unknown",
	},
	{
		.key = "ro.bootmode",
		.value = "normal",
	},
	{
		.key = "ro.build.characteristics",
		.value = "default",
	},
	{
		.key = "ro.build.cta",
		.value = "noncta",
	},
	{
		.key = "ro.build.date",
		.value = "Wed Aug  2 21:54:37 CST 2017",
	},
	{
		.key = "ro.build.date.utc",
		.value = "1501682077",
	},
	{
		.key = "ro.build.description",
		.value = "meizu_PRO7Plus-user 7.0 NRD90M 1501682079 release-keys",
	},
	{
		.key = "ro.build.display.id",
		.value = "Flyme 6.1.2.2A",
	},
	{
		.key = "ro.build.fingerprint",
		.value = "Meizu/meizu_PRO7Plus/PRO7Plus:7.0/NRD90M/1501682079:user/release-keys",
	},
	{
		.key = "ro.build.flavor",
		.value = "full_mz6799_6m_v2_2k_n-user",
	},
	{
		.key = "ro.build.host",
		.value = "mz-builder-5",
	},
	{
		.key = "ro.build.id",
		.value = "NRD90M",
	},
	{
		.key = "ro.build.inside.id",
		.value = "7.0-20170802214020",
	},
	{
		.key = "ro.build.mask.id",
		.value = "7.0-1501681220_stable",
	},
	{
		.key = "ro.build.product",
		.value = "PRO7Plus",
	},
	{
		.key = "ro.build.tags",
		.value = "release-keys",
	},
	{
		.key = "ro.build.type",
		.value = "user",
	},
	{
		.key = "ro.build.user",
		.value = "flyme",
	},
	{
		.key = "ro.build.version.all_codenames",
		.value = "REL",
	},
	{
		.key = "ro.build.version.base_os",
		.value = "",
	},
	{
		.key = "ro.build.version.codename",
		.value = "REL",
	},
	{
		.key = "ro.build.version.incremental",
		.value = "1501682079",
	},
	{
		.key = "ro.build.version.preview_sdk",
		.value = "0",
	},
	{
		.key = "ro.build.version.release",
		.value = "7.0",
	},
	{
		.key = "ro.build.version.sdk",
		.value = "24",
	},
	{
		.key = "ro.build.version.security_patch",
		.value = "2017-04-05",
	},
	{
		.key = "ro.camera.sound.forced",
		.value = "0",
	},
	{
		.key = "ro.carrier",
		.value = "unknown",
	},
	{
		.key = "ro.cdma.cfall.disable",
		.value = "*730",
	},
	{
		.key = "ro.cdma.cfb.disable",
		.value = "*900",
	},
	{
		.key = "ro.cdma.cfb.enable",
		.value = "*90",
	},
	{
		.key = "ro.cdma.cfdf.disable",
		.value = "*680",
	},
	{
		.key = "ro.cdma.cfdf.enable",
		.value = "*68",
	},
	{
		.key = "ro.cdma.cfnr.disable",
		.value = "*920",
	},
	{
		.key = "ro.cdma.cfnr.enable",
		.value = "*92",
	},
	{
		.key = "ro.cdma.cfu.disable",
		.value = "*720",
	},
	{
		.key = "ro.cdma.cfu.enable",
		.value = "*72",
	},
	{
		.key = "ro.cdma.cw.disable",
		.value = "*740",
	},
	{
		.key = "ro.cdma.cw.enable",
		.value = "*74",
	},
	{
		.key = "ro.com.android.dateformat",
		.value = "MM-dd-yyyy",
	},
	{
		.key = "ro.com.android.mobiledata",
		.value = "true",
	},
	{
		.key = "ro.config.alarm_alert",
		.value = "19_Waltz.ogg",
	},
	{
		.key = "ro.config.calendar_sound",
		.value = "03_Doorbell.ogg",
	},
	{
		.key = "ro.config.email_sound",
		.value = "02_Reminder.ogg",
	},
	{
		.key = "ro.config.mms_sound",
		.value = "01_Triumph.ogg",
	},
	{
		.key = "ro.config.notification_sound",
		.value = "02_Reminder.ogg",
	},
	{
		.key = "ro.config.ringtone",
		.value = "03_Flyme.ogg",
	},
	{
		.key = "ro.crypto.state",
		.value = "unencrypted",
	},
	{
		.key = "ro.dalvik.vm.native.bridge",
		.value = "0",
	},
	{
		.key = "ro.debuggable",
		.value = "0",
	},
	{
		.key = "ro.device_owner",
		.value = "false",
	},
	{
		.key = "ro.email_support_ucs2",
		.value = "0",
	},
	{
		.key = "ro.expect.recovery_id",
		.value = "0x89560126b36ef1427a8df246bc8b28e54e31ce82000000000000000000000000",
	},
	{
		.key = "ro.flyme.device.legal",
		.value = "1",
	},
	{
		.key = "ro.flyme.published",
		.value = "true",
	},
	{
		.key = "ro.flyme.root.state",
		.value = "1",
	},
	{
		.key = "ro.flyme_softsim_mtee_enable",
		.value = "1",
	},
	{
		.key = "ro.frp.pst",
		.value = "/dev/block/platform/bootdevice/by-name/frp",
	},
	{
		.key = "ro.hardware",
		.value = "mt6799",
	},
	{
		.key = "ro.hardware.hifi.support",
		.value = "true",
	},
	{
		.key = "ro.have_aacencode_feature",
		.value = "1",
	},
	{
		.key = "ro.have_aee_feature",
		.value = "1",
	},
	{
		.key = "ro.hwui.disable_asset_atlas",
		.value = "true",
	},
	{
		.key = "ro.hwui.drop_shadow_cache_size",
		.value = "8",
	},
	{
		.key = "ro.hwui.fbo_cache_size",
		.value = "60",
	},
	{
		.key = "ro.hwui.gradient_cache_size",
		.value = "4",
	},
	{
		.key = "ro.hwui.layer_cache_size",
		.value = "60",
	},
	{
		.key = "ro.hwui.path_cache_size",
		.value = "60",
	},
	{
		.key = "ro.hwui.r_buffer_cache_size",
		.value = "9",
	},
	{
		.key = "ro.hwui.text_large_cache_height",
		.value = "1024",
	},
	{
		.key = "ro.hwui.text_large_cache_width",
		.value = "2048",
	},
	{
		.key = "ro.hwui.text_small_cache_height",
		.value = "1024",
	},
	{
		.key = "ro.hwui.text_small_cache_width",
		.value = "1024",
	},
	{
		.key = "ro.hwui.texture_cache_flushrate",
		.value = "0.4",
	},
	{
		.key = "ro.hwui.texture_cache_size",
		.value = "120",
	},
	{
		.key = "ro.kernel.zio",
		.value = "38,108,105,16",
	},
	{
		.key = "ro.ksc5601_write",
		.value = "0",
	},
	{
		.key = "ro.mediatek.chip_ver",
		.value = "S01",
	},
	{
		.key = "ro.mediatek.platform",
		.value = "MT6799",
	},
	{
		.key = "ro.mediatek.project.path",
		.value = "device/mediatek/mz6799_6m_v2_2k_n",
	},
	{
		.key = "ro.mediatek.version.branch",
		.value = "alps-trunk-n0.tk",
	},
	{
		.key = "ro.mediatek.version.release",
		.value = "alps-mp-n0.mp8",
	},
	{
		.key = "ro.mediatek.version.sdk",
		.value = "4",
	},
	{
		.key = "ro.mediatek.wlan.p2p",
		.value = "1",
	},
	{
		.key = "ro.mediatek.wlan.wsc",
		.value = "1",
	},
	{
		.key = "ro.meizu.appid",
		.value = "M1793:2598587-V017-M1793-SDC:Synaptics:174000",
	},
	{
		.key = "ro.meizu.autorecorder",
		.value = "true",
	},
	{
		.key = "ro.meizu.build.number",
		.value = "201708022204",
	},
	{
		.key = "ro.meizu.build.spt",
		.value = "0",
	},
	{
		.key = "ro.meizu.contactmsg.auth",
		.value = "false",
	},
	{
		.key = "ro.meizu.customize.pccw",
		.value = "false",
	},
	{
		.key = "ro.meizu.ess.support",
		.value = "1",
	},
	{
		.key = "ro.meizu.hardware.battery",
		.value = "ATL",
	},
	{
		.key = "ro.meizu.hardware.chargerver",
		.value = "V1.0.0_20170608",
	},
	{
		.key = "ro.meizu.hardware.dpi",
		.value = "640",
	},
	{
		.key = "ro.meizu.hardware.psn",
		.value = "793QZZ164B00AC12",
	},
	{
		.key = "ro.meizu.hardware.sub_dpi",
		.value = "320",
	},
	{
		.key = "ro.meizu.hardware.ufs",
		.value = "KLUCG4J1ED-B0C1",
	},
	{
		.key = "ro.meizu.hardware.version",
		.value = "0x79301001",
	},
	{
		.key = "ro.meizu.pcb.version",
		.value = "0x27",
	},
	{
		.key = "ro.meizu.permanentkey",
		.value = "false",
	},
	{
		.key = "ro.meizu.product.model",
		.value = "M7930",
	},
	{
		.key = "ro.meizu.project.id",
		.value = "m1793-6",
	},
	{
		.key = "ro.meizu.published.type",
		.value = "prd",
	},
	{
		.key = "ro.meizu.region.enable",
		.value = "true",
	},
	{
		.key = "ro.meizu.security",
		.value = "false",
	},
	{
		.key = "ro.meizu.setupwizard.flyme",
		.value = "true",
	},
	{
		.key = "ro.meizu.setupwizard.setlang",
		.value = "true",
	},
	{
		.key = "ro.meizu.sip.support",
		.value = "true",
	},
	{
		.key = "ro.meizu.storage.manufacturer",
		.value = "SAMSUNG",
	},
	{
		.key = "ro.meizu.subappid",
		.value = "tpid=M1793_FT6336_V13-0x31_BN\nColor=Black",
	},
	{
		.key = "ro.meizu.tpid",
		.value = "0x174000",
	},
	{
		.key = "ro.meizu.tptype",
		.value = "Black",
	},
	{
		.key = "ro.meizu.upgrade.config",
		.value = "false",
	},
	{
		.key = "ro.meizu.visualvoicemail",
		.value = "true",
	},
	{
		.key = "ro.meizu.voip.support",
		.value = "false",
	},
	{
		.key = "ro.meizu_soter_support",
		.value = "1",
	},
	{
		.key = "ro.mount.fs",
		.value = "EXT4",
	},
	{
		.key = "ro.mtk_aal_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_afw_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_agps_app",
		.value = "1",
	},
	{
		.key = "ro.mtk_audio_tuning_tool_ver",
		.value = "V2.2",
	},
	{
		.key = "ro.mtk_benchmark_boost_tp",
		.value = "1",
	},
	{
		.key = "ro.mtk_bg_power_saving_ui",
		.value = "1",
	},
	{
		.key = "ro.mtk_bip_scws",
		.value = "1",
	},
	{
		.key = "ro.mtk_blulight_def_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_bt_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_c2k_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_cam_dualdenoise_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_cam_img_refocus_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_cam_lomo_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_cam_mfb_support",
		.value = "3",
	},
	{
		.key = "ro.mtk_ct4greg_app",
		.value = "1",
	},
	{
		.key = "ro.mtk_cta_drm_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_cta_set",
		.value = "1",
	},
	{
		.key = "ro.mtk_deinterlace_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_devreg_app",
		.value = "1",
	},
	{
		.key = "ro.mtk_dhcpv6c_wifi",
		.value = "1",
	},
	{
		.key = "ro.mtk_dialer_search_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_dre30_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_dual_mic_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_eap_sim_aka",
		.value = "1",
	},
	{
		.key = "ro.mtk_enable_md1",
		.value = "1",
	},
	{
		.key = "ro.mtk_enable_md3",
		.value = "1",
	},
	{
		.key = "ro.mtk_external_sim_only_slots",
		.value = "0",
	},
	{
		.key = "ro.mtk_external_sim_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_fd_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_gps_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_hdr_video_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_is_tablet",
		.value = "0",
	},
	{
		.key = "ro.mtk_log_hide_gps",
		.value = "0",
	},
	{
		.key = "ro.mtk_lte_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_md_direct_tethering",
		.value = "1",
	},
	{
		.key = "ro.mtk_md_world_mode_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_microtrust_tee_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_modem_monitor_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_multiple_ims_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_oma_drm_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_omacp_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_perf_fast_start_win",
		.value = "0",
	},
	{
		.key = "ro.mtk_perf_response_time",
		.value = "1",
	},
	{
		.key = "ro.mtk_perf_simple_start_win",
		.value = "1",
	},
	{
		.key = "ro.mtk_perfservice_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_pow_perf_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_pq_color_mode",
		.value = "1",
	},
	{
		.key = "ro.mtk_pq_support",
		.value = "3",
	},
	{
		.key = "ro.mtk_protocol1_rat_config",
		.value = "C/Lf/Lt/W/T/G",
	},
	{
		.key = "ro.mtk_res_switch",
		.value = "1",
	},
	{
		.key = "ro.mtk_rild_read_imsi",
		.value = "1",
	},
	{
		.key = "ro.mtk_search_db_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_send_rr_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_shared_sdcard",
		.value = "1",
	},
	{
		.key = "ro.mtk_sim_hot_swap",
		.value = "1",
	},
	{
		.key = "ro.mtk_sim_hot_swap_common_slot",
		.value = "1",
	},
	{
		.key = "ro.mtk_slow_motion_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_telephony_switch",
		.value = "1",
	},
	{
		.key = "ro.mtk_tetheringipv6_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_ufs_booting",
		.value = "1",
	},
	{
		.key = "ro.mtk_vilte_ut_support",
		.value = "0",
	},
	{
		.key = "ro.mtk_wapi_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wappush_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wfd_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_widevine_drm_l3_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wifi_mcc_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_wlan_support",
		.value = "1",
	},
	{
		.key = "ro.mtk_world_phone_policy",
		.value = "0",
	},
	{
		.key = "ro.mtk_zsdhdr_support",
		.value = "1",
	},
	{
		.key = "ro.num_md_protocol",
		.value = "2",
	},
	{
		.key = "ro.oem_unlock_supported",
		.value = "1",
	},
	{
		.key = "ro.opengles.version",
		.value = "196610",
	},
	{
		.key = "ro.product.board",
		.value = "PRO7Plus",
	},
	{
		.key = "ro.product.brand",
		.value = "Meizu",
	},
	{
		.key = "ro.product.cpu.abi",
		.value = "arm64-v8a",
	},
	{
		.key = "ro.product.cpu.abilist",
		.value = "arm64-v8a,armeabi-v7a,armeabi",
	},
	{
		.key = "ro.product.cpu.abilist32",
		.value = "armeabi-v7a,armeabi",
	},
	{
		.key = "ro.product.cpu.abilist64",
		.value = "arm64-v8a",
	},
	{
		.key = "ro.product.device",
		.value = "PRO7Plus",
	},
	{
		.key = "ro.product.flyme.model",
		.value = "m1793",
	},
	{
		.key = "ro.product.locale",
		.value = "en-US",
	},
	{
		.key = "ro.product.manufacturer",
		.value = "Meizu",
	},
	{
		.key = "ro.product.mobile.name",
		.value = "M1793",
	},
	{
		.key = "ro.product.model",
		.value = "PRO 7 Plus",
	},
	{
		.key = "ro.product.name",
		.value = "meizu_PRO7Plus",
	},
	{
		.key = "ro.product.perf.config",
		.value = "M1793_base",
	},
	{
		.key = "ro.recovery.matrix.ver",
		.value = "VER_20170616_00",
	},
	{
		.key = "ro.recovery_id",
		.value = "0x89560126b36ef1427a8df246bc8b28e54e31ce82000000000000000000000000",
	},
	{
		.key = "ro.revision",
		.value = "0",
	},
	{
		.key = "ro.runtime.firstboot",
		.value = "1508189178888",
	},
	{
		.key = "ro.secure",
		.value = "1",
	},
	{
		.key = "ro.serialno",
		.value = "793QBDR6227XF",
	},
	{
		.key = "ro.sf.hwrotation",
		.value = "0",
	},
	{
		.key = "ro.sf.lcd_density",
		.value = "640",
	},
	{
		.key = "ro.sim_me_lock_mode",
		.value = "0",
	},
	{
		.key = "ro.sim_refresh_reset_by_modem",
		.value = "1",
	},
	{
		.key = "ro.soc.vendor",
		.value = "MTK",
	},
	{
		.key = "ro.support.rpmb",
		.value = "1",
	},
	{
		.key = "ro.sys.sdcardfs",
		.value = "1",
	},
	{
		.key = "ro.sys.usb.bicr",
		.value = "yes",
	},
	{
		.key = "ro.sys.usb.charging.only",
		.value = "yes",
	},
	{
		.key = "ro.sys.usb.mtp.whql.enable",
		.value = "0",
	},
	{
		.key = "ro.sys.usb.storage.type",
		.value = "mtp",
	},
	{
		.key = "ro.telephony.default_network",
		.value = "10,10",
	},
	{
		.key = "ro.telephony.sim.count",
		.value = "2",
	},
	{
		.key = "ro.tethering.bridge.interface",
		.value = "mdbr0",
	},
	{
		.key = "ro.ussd_ksc5601",
		.value = "0",
	},
	{
		.key = "ro.wifi.channels",
		.value = "",
	},
	{
		.key = "ro.wlan.mtk.wifi.5g",
		.value = "1",
	},
	{
		.key = "ro.zygote",
		.value = "zygote64_32",
	},
	{
		.key = "ro.zygote.preload.enable",
		.value = "0",
	},
	{
		.key = "security.perf_harden",
		.value = "1",
	},
	{
		.key = "selinux.reload_policy",
		.value = "1",
	},
	{
		.key = "service.bootanim.exit",
		.value = "1",
	},
	{
		.key = "service.cat.install.on",
		.value = "0",
	},
	{
		.key = "service.cat.install.on.2",
		.value = "0",
	},
	{
		.key = "service.cat.install.on.3",
		.value = "0",
	},
	{
		.key = "service.cat.install.on.4",
		.value = "0",
	},
	{
		.key = "service.nvram_init",
		.value = "Ready",
	},
	{
		.key = "service.wcn.coredump.mode",
		.value = "2",
	},
	{
		.key = "service.wcn.driver.ready",
		.value = "yes",
	},
	{
		.key = "soter.encrypt.state",
		.value = "OK",
	},
	{
		.key = "soter.teei.init",
		.value = "INIT_OK",
	},
	{
		.key = "sys.boot.reason",
		.value = "0",
	},
	{
		.key = "sys.boot_completed",
		.value = "1",
	},
	{
		.key = "sys.ipo.pwrdncap",
		.value = "2",
	},
	{
		.key = "sys.ipowin.done",
		.value = "1",
	},
	{
		.key = "sys.lowstorage_flag",
		.value = "0",
	},
	{
		.key = "sys.meizu.m35x.white.config",
		.value = "false",
	},
	{
		.key = "sys.meizu.white.config",
		.value = "false",
	},
	{
		.key = "sys.mtk_md_direct_tether_enable",
		.value = "true",
	},
	{
		.key = "sys.oem_unlock_allowed",
		.value = "0",
	},
	{
		.key = "sys.sysctl.extra_free_kbytes",
		.value = "43200",
	},
	{
		.key = "sys.sysctl.tcp_def_init_rwnd",
		.value = "60",
	},
	{
		.key = "sys.usb.charging",
		.value = "no",
	},
	{
		.key = "sys.usb.config",
		.value = "mtp,adb",
	},
	{
		.key = "sys.usb.configfs",
		.value = "0",
	},
	{
		.key = "sys.usb.ffs.ready",
		.value = "1",
	},
	{
		.key = "sys.usb.state",
		.value = "mtp,adb",
	},
	{
		.key = "sys.usb.vid",
		.value = "2A45",
	},
	{
		.key = "telephony.lteOnCdmaDevice",
		.value = "1",
	},
	{
		.key = "vold.has_adoptable",
		.value = "0",
	},
	{
		.key = "vold.path.internal_storage",
		.value = "/storage/emulated/0",
	},
	{
		.key = "vold.post_fs_data_done",
		.value = "1",
	},
	{
		.key = "vold.support_external_sd",
		.value = "1",
	},
	{
		.key = "wfd.dummy.enable",
		.value = "1",
	},
	{
		.key = "wfd.iframesize.level",
		.value = "0",
	},
	{
		.key = "wifi.direct.interface",
		.value = "p2p0",
	},
	{
		.key = "wifi.interface",
		.value = "wlan0",
	},
	{
		.key = "wifi.tethering.interface",
		.value = "ap0",
	},
	{
		.key = "wlan.dbg",
		.value = "false",
	},
	{
		.key = "wlan.driver.status",
		.value = "ok",
	},
	{
		.key = "wlan.wfd.security.image",
		.value = "1",
	},
	{NULL},
};
#endif /* __ANDROID__ */
